@@ -57,7 +57,7 @@ from openmdao.surrogate_models.response_surface import ResponseSurface
 from openmdao.surrogate_models.surrogate_model import SurrogateModel, \
     MultiFiSurrogateModel
 
-from openmdao.utils.indexer import slicer
+from openmdao.utils.indexer import slicer, indexer, to_numpy_style
 from openmdao.utils.find_cite import print_citations
 from openmdao.utils.spline_distributions import cell_centered
 from openmdao.utils.spline_distributions import sine_distribution
