@@ -9,6 +9,7 @@ import re
 
 try:
     from numpydoc.docscrape import NumpyDocString
+    from numpydoc import validate
 except ImportError:
     NumpyDocString = None
 
@@ -24,6 +25,14 @@ exclude = [
     'assets',  # Script for processing N2 icons.
 ]
 
+# Error Codes to Ignore
+ignore = [
+    'ES01',    # No extended summary found
+    'EX01',    # No examples section found
+    'SA01',    # See Also section not found
+    'SS05',    # Summary must start with infinitive verb, not third person (e.g. use "Generate" instead of "Generates")')
+]
+
 # we will build a list of dirs in which to do linting.
 directories = []
 
@@ -494,72 +503,77 @@ class LintTestCase(unittest.TestCase):
             else:
                 failures[key] = new_failures
 
-    def test_docstrings(self):
-        print_info = False
-
+    def _failure_dict(self, full_class_path, result):
         failures = {}
 
+        for error_tuple in result['errors']:
+            if error_tuple[0] not in ignore:
+                if full_class_path not in failures:
+                    failures[full_class_path] = []
+                msg = f"{error_tuple[0]}: {error_tuple[1]}"
+                failures[full_class_path].append(msg)
+
+        return failures
+
+    def test_docstrings(self):
+        failures = {}
         # Loop over directories
-        for dir_name in directories:
-            dirpath = dir_name
-            if print_info:
-                print('-'*len(dir_name))
-                print(dir_name)
-                print('-'*len(dir_name))
+        for dirpath in sorted(directories):
 
             # Loop over files
-            for file_name in os.listdir(dirpath):
-                if not file_name.startswith("_") and file_name[-3:] == '.py' and not os.path.isdir(file_name):
-                    if print_info:
-                        print(file_name)
+            for file_name in sorted(os.listdir(dirpath)):
+                if not file_name.startswith("_") and file_name[-3:] == '.py' \
+                   and not os.path.isdir(file_name):
 
-                    # to construct module name, remove part of abs path that
+                    # To construct module name, remove part of abs path that
                     # precedes 'openmdao', and then replace '/' with '.' in the remainder.
-                    mod1 = re.sub(r'.*openmdao', 'openmdao', dir_name).replace('/', '.')
+                    mod1 = re.sub(r'.*openmdao', 'openmdao', dirpath).replace('/', '.')
 
-                    # then, get rid of the '.py' to get final part of module name.
+                    # Then, get rid of the '.py' to get final part of module name.
                     mod2 = file_name[:-3]
 
-                    module_name = '{}.{}'.format(mod1, mod2)
+                    module_name = f'{mod1}.{mod2}'
 
                     try:
                         mod = importlib.import_module(module_name)
                     except ImportError as err:
-                        if print_info:
-                            print('Skipped:', err)
+                        print('Skipped:', err)
                         # e.g. PETSc is not installed
                         continue
 
-                    # Loop over classes
                     classes = [x for x in dir(mod)
                                if not x.startswith('_') and inspect.isclass(getattr(mod, x)) and
                                getattr(mod, x).__module__ == module_name]
 
+                    # Loop over classes.
                     for class_name in classes:
-                        if print_info:
-                            print(' '*4, class_name)
-                        clss = getattr(mod, class_name)
-
-                        # skip namedtuples
-                        if issubclass(clss, tuple):
+                        full_class_path = f'{module_name}.{class_name}'
+                        try:
+                            result = validate.validate(full_class_path)
+                        except:
                             continue
 
-                        self.check_class(dir_name, file_name, class_name, clss,
-                                         failures)
+                        failures.update(self._failure_dict(full_class_path, result))
+
+                        clss = getattr(mod, class_name)
 
-                        # Loop over methods
                         methods = [x for x in dir(clss)
-                                   if (inspect.ismethod(getattr(clss, x)) or inspect.isfunction(getattr(clss, x))) and
+                                   if (inspect.ismethod(getattr(clss, x)) or
+                                       inspect.isfunction(getattr(clss, x))) and
                                    x in clss.__dict__]
+
+                        # Loop over class methods.
                         for method_name in methods:
-                            if print_info:
-                                print(' '*8, method_name)
-                            method = getattr(clss, method_name)
 
-                            self.check_method(dir_name, file_name, class_name,
-                                              method_name, method, failures)
+                            if not method_name.startswith('_'):
+                                full_method_path = f'{module_name}.{class_name}.{method_name}'
+                                try:
+                                    result = validate.validate(full_method_path)
+                                except:
+                                    continue
+
+                                failures.update(self._failure_dict(full_class_path, result))
 
-                    # Loop over functions
                     tree = ast.parse(inspect.getsource(mod))
 
                     if hasattr(tree, 'body'):
@@ -567,21 +581,26 @@ class LintTestCase(unittest.TestCase):
                     else:
                         funcs = []
 
+                    # Loop over standalone functions.
                     for func_name in funcs:
                         if not func_name.startswith('_'):
-                            func = getattr(mod, func_name)
-                            self.check_function(dir_name, file_name, func_name,
-                                                func, failures)
+                            full_function_path = f'{module_name}.{func_name}'
+                            try:
+                                result = validate.validate(full_function_path)
+                            except:
+                                continue
+
+                            failures.update(self._failure_dict(full_class_path, result))
 
         if failures:
             msg = '\n'
             count = 0
             for key in failures:
-                msg += '{0}\n'.format(key)
+                msg += f'{key}\n'
                 count += len(failures[key])
                 for failure in failures[key]:
-                    msg += '    {0}\n'.format(failure)
-            msg += 'Found {0} issues in docstrings'.format(count)
+                    msg += f'    {failure}\n'
+            msg += f'Found {count} issues in docstrings'
             self.fail(msg)
 
 
