@@ -20,260 +20,260 @@ except ImportError:
 import openmdao.api as om
 from openmdao.components.exec_comp import _expr_dict, _temporary_expr_dict
 from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials, assert_warning
-from openmdao.warnings import OMDeprecationWarning
+from openmdao.utils.om_warnings import OMDeprecationWarning
 
 _ufunc_test_data = {
     'min': {
         'str': 'f=min(x)',
         'check_func': np.min,
-        'args': { 'f': {'value': np.zeros(6)},
-                  'x': {'value': np.random.random(6)}}},
+        'args': { 'f': {'val': np.zeros(6)},
+                  'x': {'val': np.random.random(6)}}},
     'max': {
         'str': 'f=max(x)',
         'check_func': np.max,
-        'args': { 'f': {'value': np.zeros(6)},
-                  'x': {'value': np.random.random(6)}}},
+        'args': { 'f': {'val': np.zeros(6)},
+                  'x': {'val': np.random.random(6)}}},
     'diff': {
         'str': 'f=diff(x)',
         'check_func': np.diff,
-        'args': { 'f': {'value': np.zeros(5)},
-                  'x': {'value': np.random.random(6)}}},
+        'args': { 'f': {'val': np.zeros(5)},
+                  'x': {'val': np.random.random(6)}}},
     'abs': {
         'str': 'f=abs(x)',
         'check_func': np.abs,
-        'args': { 'f': {'value': np.zeros(6)},
-                  'x': {'value': np.random.random(6)}}},
+        'args': { 'f': {'val': np.zeros(6)},
+                  'x': {'val': np.random.random(6)}}},
     'acos': {
         'str': 'f=acos(x)',
         'check_func': np.arccos,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6) - 0.5}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6) - 0.5}}},
     'arccos': {
         'str': 'f=arccos(x)',
         'check_func': np.arccos,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6) - 0.5}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6) - 0.5}}},
     'arccosh': {
         'str': 'f=arccosh(x)',
         'check_func': np.arccosh,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': 1.1 + np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': 1.1 + np.random.random(6)}}},
     'acosh': {
         'str': 'f=acosh(x)',
         'check_func': np.arccosh,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': 1.1 + np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': 1.1 + np.random.random(6)}}},
     'arange': {
         'str': 'f=arange(0,10,2)',
         'check_val': np.arange(0, 10, 2),
-        'args': {'f': {'value': np.zeros(5)}}},
+        'args': {'f': {'val': np.zeros(5)}}},
     'arcsin': {
         'str': 'f=arcsin(x)',
         'check_func': np.arcsin,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6) - .5}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6) - .5}}},
     'arcsinh': {
         'str': 'f=arcsinh(x)',
         'check_func': np.arcsinh,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'asinh': {
         'str': 'f=asinh(x)',
         'check_func': np.arcsinh,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'asin': {
         'str': 'f=asin(x)',
         'check_func': np.arcsin,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6) - .5}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6) - .5}}},
     'arctan': {
         'str': 'f=arctan(x)',
         'check_func': np.arctan,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'arctan2': {
         'str': 'f=arctan2(y, x)',
         'check_val': np.array([-2.35619449, -0.78539816,  0.78539816,  2.35619449]),
-        'args': {'f': {'value': np.zeros(4)},
-                 'x': {'value': np.array([-1, +1, +1, -1])},
-                 'y': {'value': np.array([-1, -1, +1, +1])}}},
+        'args': {'f': {'val': np.zeros(4)},
+                 'x': {'val': np.array([-1, +1, +1, -1])},
+                 'y': {'val': np.array([-1, -1, +1, +1])}}},
     'atan': {
         'str': 'f=atan(x)',
         'check_func': np.arctan,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'cos': {
         'str': 'f=cos(x)',
         'check_func': np.cos,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'cosh': {
         'str': 'f=cosh(x)',
         'check_func': np.cosh,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'dot': {
         'str': 'f=dot(x, y)',
         'check_func': np.dot,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6)}}},
     'e': {
         'str': 'f=e',
         'check_val': np.e,
-        'args': {'f': {'value': 0.0}}},
+        'args': {'f': {'val': 0.0}}},
     'erf': {
         'str': 'f=erf(x)',
         'check_func': scipy.special.erf,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'erfc': {
         'str': 'f=erfc(x)',
         'check_func': scipy.special.erfc,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'exp': {
         'str': 'f=exp(x)',
         'check_func': np.exp,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'expm1': {
         'str': 'f=expm1(x)',
         'check_func': np.expm1,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'fmax': {
         'str': 'f=fmax(x, y)',
         'check_func': np.fmax,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6)}}},
     'fmin': {
         'str': 'f=fmin(x, y)',
         'check_func': np.fmin,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6)}}},
     'inner': {
         'str': 'f=inner(x, y)',
         'check_func': np.inner,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6)}}},
     'isinf': {
         'str': 'f=isinf(x)',
         'check_func': np.isinf,
-        'args': {'f': {'value': np.zeros(3)},
-                 'x': {'value': [0, np.inf, 5.0]}}},
+        'args': {'f': {'val': np.zeros(3)},
+                 'x': {'val': [0, np.inf, 5.0]}}},
     'isnan': {
         'str': 'f=isnan(x)',
         'check_func': np.isnan,
-        'args': {'f': {'value': np.zeros(3)},
-                 'x': {'value': [0, np.nan, np.nan]}}},
+        'args': {'f': {'val': np.zeros(3)},
+                 'x': {'val': [0, np.nan, np.nan]}}},
     'kron': {
         'str': 'f=kron(x, y)',
         'check_func': np.kron,
-        'args': {'f': {'value': np.zeros(36)},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(36)},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6)}}},
     'linspace': {
         'str': 'f=linspace(0,10,50)',
         'check_val': np.linspace(0, 10, 50),
-        'args': {'f': {'value': np.zeros(50)}}},
+        'args': {'f': {'val': np.zeros(50)}}},
     'log': {
         'str': 'f=log(x)',
         'check_func': np.log,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6) + 0.1}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6) + 0.1}}},
     'log10': {
         'str': 'f=log10(x)',
         'check_func': np.log10,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6) + 0.1}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6) + 0.1}}},
     'log1p': {
         'str': 'f=log1p(x)',
         'check_func': np.log1p,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'matmul': {
         'str': 'f=matmul(x, y)',
         'check_func': np.matmul,
-        'args': {'f': {'value': np.zeros((3, 1))},
-                 'x': {'value': np.random.random((3, 3))},
-                 'y': {'value': np.random.random((3, 1))}}},
+        'args': {'f': {'val': np.zeros((3, 1))},
+                 'x': {'val': np.random.random((3, 3))},
+                 'y': {'val': np.random.random((3, 1))}}},
     'maximum': {
         'str': 'f=maximum(x, y)',
         'check_func': np.maximum,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6)}}},
     'minimum': {
         'str': 'f=minimum(x, y)',
         'check_func': np.minimum,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6)}}},
     'ones': {
         'str': 'f=ones(21)',
         'check_val': np.ones(21),
-         'args': {'f': {'value': np.zeros(21)}}},
+         'args': {'f': {'val': np.zeros(21)}}},
     'outer': {
         'str': 'f=outer(x, y)',
         'check_func': np.outer,
-        'args': {'f': {'value': np.zeros((6, 6))},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros((6, 6))},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6)}}},
     'pi': {
         'str': 'f=pi',
         'check_val': np.pi,
-        'args': {'f': {'value': 0.0}}},
+        'args': {'f': {'val': 0.0}}},
     'power': {
         'str': 'f=power(x, y)',
         'check_func': np.power,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)},
-                 'y': {'value': np.random.random(6) + 1.0}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)},
+                 'y': {'val': np.random.random(6) + 1.0}}},
     'prod': {
         'str': 'f=prod(x)',
         'check_func': np.prod,
-        'args': {'f': {'value': 0.0},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': 0.0},
+                 'x': {'val': np.random.random(6)}}},
     'sin': {
         'str': 'f=sin(x)',
         'check_func': np.sin,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'sinh': {
         'str': 'f=sinh(x)',
         'check_func': np.sinh,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'sum': {
         'str': 'f=sum(x)',
         'check_func': np.sum,
-        'args': {'f': {'value': 0.0},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': 0.0},
+                 'x': {'val': np.random.random(6)}}},
     'tan': {
         'str': 'f=tan(x)',
         'check_func': np.tan,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'tanh': {
         'str': 'f=tanh(x)',
         'check_func': np.tanh,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}}},
     'tensordot': {
         'str': 'f=tensordot(x, y)',
         'check_func': np.tensordot,
-        'args': {'f': {'value': 0.0},
-                 'x': {'value': np.random.random((6, 6))},
-                 'y': {'value': np.random.random((6, 6))}}},
+        'args': {'f': {'val': 0.0},
+                 'x': {'val': np.random.random((6, 6))},
+                 'y': {'val': np.random.random((6, 6))}}},
     'zeros': {
         'str': 'f=zeros(21)',
         'check_val': np.zeros(21),
-        'args': {'f': {'value': np.zeros(21)}}},
+        'args': {'f': {'val': np.zeros(21)}}},
 }
 
 
@@ -281,8 +281,8 @@ _ufunc_test_data = {
 if LooseVersion(scipy.__version__) >= LooseVersion("1.5.0"):
     _ufunc_test_data['factorial'] = {
         'str': 'f=factorial(x)',
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}},
         'error': (RuntimeError,
                   "The 'factorial' function is not supported for SciPy "
                   f"versions >= 1.5, current version: {scipy.__version__}")
@@ -291,8 +291,8 @@ else:
     _ufunc_test_data['factorial'] = {
         'str': 'f=factorial(x)',
         'check_func': scipy.special.factorial,
-        'args': {'f': {'value': np.zeros(6)},
-                 'x': {'value': np.random.random(6)}},
+        'args': {'f': {'val': np.zeros(6)},
+                 'x': {'val': np.random.random(6)}},
         'warning': (OMDeprecationWarning,
                     "The 'factorial' function is deprecated. "
                     "It is no longer supported for SciPy versions >= 1.5.")
@@ -311,14 +311,6 @@ class TestExecComp(unittest.TestCase):
         with assert_warning(UserWarning, "'comp' <class ExecComp>: The following partial derivatives have not been declared so they are assumed to be zero: ['z' wrt 'y']."):
             p.final_setup()
 
-    def test_no_expr(self):
-        prob = om.Problem()
-        prob.model.add_subsystem('C1', om.ExecComp())
-        with self.assertRaises(Exception) as context:
-            prob.setup()
-        self.assertEqual(str(context.exception),
-                         "'C1' <class ExecComp>: No valid expressions provided to ExecComp(): [].")
-
     def test_colon_vars(self):
         prob = om.Problem()
         prob.model.add_subsystem('C1', om.ExecComp('y=foo:bar+1.'))
@@ -344,7 +336,7 @@ class TestExecComp(unittest.TestCase):
             prob.setup()
         self.assertEqual(str(context.exception),
                          "'C1' <class ExecComp>: the following metadata names were not recognized for "
-                         "variable 'x': ['high', 'low', 'val']")
+                         "variable 'x': ['high', 'low']")
 
     def test_name_collision_const(self):
         prob = om.Problem()
@@ -429,7 +421,7 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         prob.model.add_subsystem('indep', om.IndepVarComp('x', 100.0, units='cm'))
         C1 = prob.model.add_subsystem('C1', om.ExecComp('y=x+z+1.',
-                                                        x={'value': 2.0, 'units': 'm'},
+                                                        x={'val': 2.0, 'units': 'm'},
                                                         y={'units': 'm'},
                                                         z=2.0))
         prob.model.connect('indep.x', 'C1.x')
@@ -446,7 +438,7 @@ class TestExecComp(unittest.TestCase):
 
         with self.assertRaises(TypeError) as cm:
             prob.model.add_subsystem('C1', om.ExecComp('y=x+units+1.',
-                                                       x={'value': 2.0, 'units': 'm'},
+                                                       x={'val': 2.0, 'units': 'm'},
                                                        y={'units': 'm'},
                                                        units=2.0))
 
@@ -459,7 +451,7 @@ class TestExecComp(unittest.TestCase):
 
         with self.assertRaises(ValueError) as cm:
             prob.model.add_subsystem('C1', om.ExecComp('y=x+units+1.',
-                                                       x={'value': 2.0, 'units': 'm'},
+                                                       x={'val': 2.0, 'units': 'm'},
                                                        y={'units': 'm'},
                                                        units='two'))
 
@@ -469,7 +461,7 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         prob.model.add_subsystem('indep', om.IndepVarComp('x', 100.0, units='cm'))
         C1 = prob.model.add_subsystem('C1', om.ExecComp('y=x+units+1.',
-                                                        x={'value': 2.0, 'units': 'm'},
+                                                        x={'val': 2.0, 'units': 'm'},
                                                         y={'units': 'm'}))
         prob.model.connect('indep.x', 'C1.x')
 
@@ -485,7 +477,7 @@ class TestExecComp(unittest.TestCase):
 
         prob.model.add_subsystem('indep', om.IndepVarComp('x', 100.0, units='cm'))
         prob.model.add_subsystem('comp', om.ExecComp('y=x+z+1.', units='m',
-                                                     x={'value': 2.0},
+                                                     x={'val': 2.0},
                                                      z=2.0))
         prob.model.connect('indep.x', 'comp.x')
 
@@ -512,7 +504,7 @@ class TestExecComp(unittest.TestCase):
         prob = om.Problem()
         prob.model.add_subsystem('indep', om.IndepVarComp('x', 100.0, units='cm'))
         C1 = prob.model.add_subsystem('C1', om.ExecComp('y=x+z+1.', units='m',
-                                                        x={'value': 2.0, 'units': 'km'},
+                                                        x={'val': 2.0, 'units': 'km'},
                                                         z=2.0))
         prob.model.connect('indep.x', 'C1.x')
 
@@ -528,8 +520,8 @@ class TestExecComp(unittest.TestCase):
         model = p.model
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5',
-                                                x={'shape': (5,), 'value': np.zeros(5)},
-                                                y={'shape': (5,), 'value': np.zeros(5)}))
+                                                x={'shape': (5,), 'val': np.zeros(5)},
+                                                y={'shape': (5,), 'val': np.zeros(5)}))
 
         p.setup()
         p.run_model()
@@ -543,7 +535,7 @@ class TestExecComp(unittest.TestCase):
         model = p.model
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5',
-                                                x={'shape': (5,), 'value': 5},
+                                                x={'shape': (5,), 'val': 5},
                                                 y={'shape': (5,)}))
 
         with self.assertRaises(Exception) as context:
@@ -571,8 +563,8 @@ class TestExecComp(unittest.TestCase):
         model = p.model
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5', shape=(5,),
-                                                x={'value': np.zeros(5)},
-                                                y={'value': np.zeros(5)}))
+                                                x={'val': np.zeros(5)},
+                                                y={'val': np.zeros(5)}))
 
         p.setup()
         p.run_model()
@@ -600,7 +592,7 @@ class TestExecComp(unittest.TestCase):
         model = p.model
 
         model.add_subsystem('comp', om.ExecComp('y=3.0*x + 2.5', shape=(5,),
-                                                x={'value': 5}))
+                                                x={'val': 5}))
 
         with self.assertRaises(Exception) as context:
             p.setup()
@@ -974,9 +966,9 @@ class TestExecComp(unittest.TestCase):
     def test_tags(self):
         prob = om.Problem(model=om.Group())
         C1 = prob.model.add_subsystem('C1', om.ExecComp('y=x+z+1.',
-                                                     x={'value': 1.0, 'units': 'm', 'tags': 'tagx'},
+                                                     x={'val': 1.0, 'units': 'm', 'tags': 'tagx'},
                                                      y={'units': 'm', 'tags': ['tagy','tagq']},
-                                                     z={'value': 2.0, 'tags': 'tagz'},
+                                                     z={'val': 2.0, 'tags': 'tagz'},
                                                      ))
 
         prob.setup(check=False)
@@ -1031,8 +1023,6 @@ class TestExecComp(unittest.TestCase):
         self.assertEqual(sorted(outputs), [])
 
     def test_feature_has_diag_partials(self):
-        import numpy as np
-        import openmdao.api as om
 
         p = om.Problem()
         model = p.model
@@ -1051,25 +1041,7 @@ class TestExecComp(unittest.TestCase):
 
         assert_almost_equal(J, np.eye(5)*3., decimal=6)
 
-    def test_feature_simple(self):
-        import openmdao.api as om
-
-        prob = om.Problem()
-        model = prob.model
-
-        model.add_subsystem('comp', om.ExecComp('y=x+1.'))
-
-        model.set_input_defaults('comp.x', 2.0)
-
-        prob.setup()
-
-        prob.set_solver_print(level=0)
-        prob.run_model()
-
-        assert_near_equal(prob.get_val('comp.y'), 3.0, 0.00001)
-
     def test_feature_multi_output(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         model = prob.model
@@ -1088,7 +1060,6 @@ class TestExecComp(unittest.TestCase):
 
     def test_feature_multi_output2(self):
         # verify that expressions can have multiple LHS variables.
-        import openmdao.api as om
 
         prob = om.Problem()
         model = prob.model
@@ -1106,9 +1077,6 @@ class TestExecComp(unittest.TestCase):
         assert_near_equal(prob.get_val('comp.y2'), 1.0, 0.00001)
 
     def test_feature_array(self):
-        import numpy as np
-
-        import openmdao.api as om
 
         prob = om.Problem()
         model = prob.model
@@ -1125,9 +1093,6 @@ class TestExecComp(unittest.TestCase):
         assert_near_equal(prob.get_val('comp.y'), 2.0, 0.00001)
 
     def test_feature_math(self):
-        import numpy as np
-
-        import openmdao.api as om
 
         prob = om.Problem()
         model = prob.model
@@ -1145,9 +1110,6 @@ class TestExecComp(unittest.TestCase):
         assert_near_equal(prob.get_val('comp.z'), 1.0, 0.00001)
 
     def test_feature_numpy(self):
-        import numpy as np
-
-        import openmdao.api as om
 
         prob = om.Problem()
         model = prob.model
@@ -1162,15 +1124,14 @@ class TestExecComp(unittest.TestCase):
         assert_near_equal(prob['comp.y'], 6.0, 0.00001)
 
     def test_feature_metadata(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         model = prob.model
 
         model.add_subsystem('comp', om.ExecComp('z=x+y',
-                                                x={'value': 0.0, 'units': 'inch'},
-                                                y={'value': 0.0, 'units': 'inch'},
-                                                z={'value': 0.0, 'units': 'inch'}))
+                                                x={'val': 0.0, 'units': 'inch'},
+                                                y={'val': 0.0, 'units': 'inch'},
+                                                z={'val': 0.0, 'units': 'inch'}))
 
         prob.setup()
 
@@ -1183,7 +1144,6 @@ class TestExecComp(unittest.TestCase):
         assert_near_equal(prob.get_val('comp.z'), 24.0, 0.00001)
 
     def test_feature_options(self):
-        import openmdao.api as om
 
         model = om.Group()
 
@@ -1239,7 +1199,7 @@ class TestExecComp(unittest.TestCase):
         p = om.Problem()
 
         excomp = om.ExecComp('y=x',
-                             x={'value' : 3.0, 'units' : 'mm'},
+                             x={'val' : 3.0, 'units' : 'mm'},
                              y={'shape' : (1, ), 'units' : 'cm'})
 
         excomp.add_expr('z = 2.9*x',
@@ -1258,7 +1218,7 @@ class TestExecComp(unittest.TestCase):
         excomp = om.ExecComp()
 
         excomp.add_expr('z = 2.9*x',
-                        x={'value' : 3.0, 'units' : 'mm'},
+                        x={'val' : 3.0, 'units' : 'mm'},
                         z={'shape' : (1, ), 'units' : 's'})
 
         p.model.add_subsystem('comp', excomp, promotes=['*'])
@@ -1272,7 +1232,7 @@ class TestExecComp(unittest.TestCase):
         class ConfigGroup(om.Group):
             def setup(self):
                 excomp = om.ExecComp('y=x',
-                                     x={'value' : 3.0, 'units' : 'mm'},
+                                     x={'val' : 3.0, 'units' : 'mm'},
                                      y={'shape' : (1, ), 'units' : 'cm'})
 
                 self.add_subsystem('excomp', excomp, promotes=['*'])
@@ -1290,6 +1250,68 @@ class TestExecComp(unittest.TestCase):
         assert_almost_equal(p.get_val('z'), 8.7, 1e-8)
         assert_almost_equal(p.get_val('y'), 3.0, 1e-8)
 
+    def test_add_expr_configure_no_shape_or_val(self):
+
+        class ConfigGroup(om.Group):
+            def setup(self):
+                excomp = om.ExecComp('x_constraint=x',
+                                     x_constraint={'units': None},
+                                     x={'units': 's'})
+
+                self.add_subsystem('excomp', excomp, promotes=['*'])
+
+            def configure(self):
+                self.excomp.add_expr('y_constraint = y',
+                                     y_constraint={'units': None},
+                                     y={'units': 's'})
+
+        p = om.Problem()
+        p.model.add_subsystem('sub', ConfigGroup(), promotes=['*'])
+        p.setup()
+        p.set_val('x', 3.0)
+        p.set_val('y', 4.0)
+        p.run_model()
+
+        assert_almost_equal(p.get_val('x_constraint'), 3.0)
+        assert_almost_equal(p.get_val('y_constraint'), 4.0)
+
+    def test_no_expressions_until_configure(self):
+
+        class ConfigGroup(om.Group):
+            def setup(self):
+                excomp = om.ExecComp()
+
+                self.add_subsystem('excomp', excomp, promotes=['*'])
+
+            def configure(self):
+                self.excomp.add_expr('y_constraint = y**2',
+                                     y_constraint={'units': None},
+                                     y={'units': 's'})
+
+        p = om.Problem()
+        p.model.add_subsystem('sub', ConfigGroup(), promotes=['*'])
+        p.setup()
+        p.set_val('y', 4.0)
+        p.run_model()
+
+        assert_almost_equal(p.get_val('y_constraint'), 16.0)
+
+    def test_no_expressions(self):
+
+        class ConfigGroup(om.Group):
+            def setup(self):
+                excomp = om.ExecComp()
+
+                self.add_subsystem('excomp', excomp, promotes=['*'])
+
+            def configure(self):
+                pass
+
+        p = om.Problem()
+        p.model.add_subsystem('sub', ConfigGroup(), promotes=['*'])
+        p.setup()
+        p.run_model()
+
     def test_add_expr_configure_delay_defaults(self):
 
         class ConfigGroup(om.Group):
@@ -1301,7 +1323,7 @@ class TestExecComp(unittest.TestCase):
 
             def configure(self):
                 self.excomp.add_expr('z = 2.9*x',
-                                     x={'value' : 3.0, 'units' : 'mm'},
+                                     x={'val' : 3.0, 'units' : 'mm'},
                                      z={'shape' : (1, ), 'units' : 's'})
 
 
@@ -1317,12 +1339,12 @@ class TestExecComp(unittest.TestCase):
         p = om.Problem()
 
         excomp = om.ExecComp('y=x',
-                             x={'value' : 3.0, 'units' : 'mm'},
+                             x={'val' : 3.0, 'units' : 'mm'},
                              y={'shape' : (1, ), 'units' : 'cm'})
 
         with self.assertRaises(NameError) as cm:
             excomp.add_expr('z = 2.9*x',
-                            x={'value' : 3.0, 'units' : 'cm'},
+                            x={'val' : 3.0, 'units' : 'cm'},
                             z={'shape' : (1, ), 'units' : 's'})
 
         self.assertEquals(cm.exception.args[0],
@@ -1343,14 +1365,37 @@ class TestExecComp(unittest.TestCase):
         self.assertEquals(cm.exception.args[0],
                           "'zzz' <class ExecComp>: The output 'y' has already been defined by an expression.")
 
+    def test_value_deprecation(self):
+        p = om.Problem()
+
+        msg = ("'zzz' <class ExecComp>: 'value' will be deprecated in 4.0. Please use 'val' in the future.")
+
+        excomp = om.ExecComp('y=x**2', x={'value': np.ones(10)}, y={'val': np.ones(10)})
+
+        p.model.add_subsystem('zzz', excomp)
+        with assert_warning(OMDeprecationWarning, msg):
+            p.setup()
+
+    def test_val_value_error(self):
+        p = om.Problem()
+
+        msg = ("Cannot use 'val' and 'value' at the same time, use 'val'.")
+
+        excomp = om.ExecComp('y=x**2', x={'value': np.ones(10), 'val': np.ones(10)},
+                                       y={'val': np.ones(10)})
+
+        p.model.add_subsystem('zzz', excomp)
+
+        with self.assertRaises(RuntimeError) as cm:
+            p.setup()
+            self.assertEquals(cm.exception.args[0], msg)
+
     def test_feature_add_expr(self):
-        import numpy as np
-        import openmdao.api as om
 
         class ConfigGroup(om.Group):
             def setup(self):
                 excomp = om.ExecComp('y=x',
-                                     x={'value' : 3.0, 'units' : 'mm'},
+                                     x={'val' : 3.0, 'units' : 'mm'},
                                      y={'shape' : (1, ), 'units' : 'cm'})
 
                 self.add_subsystem('excomp', excomp, promotes=['*'])
@@ -1375,7 +1420,6 @@ class TestFunctionRegistration(unittest.TestCase):
     # the _temporary_expr_dict contextmanager (to avoid user confusion)
     # which keeps the contents of the ExecComp _expr_dict clean
     def featuretest_register_simple(self):
-        import openmdao.api as om
 
         om.ExecComp.register("myfunc", lambda x: x * x, complex_safe=True)
         p = om.Problem()
@@ -1387,7 +1431,6 @@ class TestFunctionRegistration(unittest.TestCase):
         assert_near_equal(J['comp.y', 'comp.x'][0][0], 4., 1e-10)
 
     def featuretest_register_simple_unsafe(self):
-        import openmdao.api as om
 
         # the following function isn't really complex unsafe, but we'll call it unsafe anyway
         # for demonstration purposes
@@ -1441,7 +1484,7 @@ class TestFunctionRegistration(unittest.TestCase):
             p.run_model()
             assert_near_equal(p['comp.area_square'], np.ones(size) * 9., 1e-6)
 
-            data = p.check_partials(out_stream=None)
+            data = p.check_partials(out_stream=None, step=1e-7)
             self.assertEqual(list(data), ['comp'])
 
     def test_register_check_partials_not_safe_err(self):
@@ -1490,7 +1533,7 @@ class TestFunctionRegistration(unittest.TestCase):
             assert_near_equal(J['comp.out2', 'comp.y'], np.eye(size) * 2. * y, 1e-11)
             assert_near_equal(J['comp.out2', 'comp.z'], np.eye(size), 1e-6)
 
-            data = p.check_partials(out_stream=None)
+            data = p.check_partials(out_stream=None, step=1e-7)
             self.assertEqual(list(data), ['comp'])
 
     def test_register_check_partials_not_safe_mult_expr_err(self):
@@ -1511,7 +1554,7 @@ class TestFunctionRegistration(unittest.TestCase):
             assert_near_equal(p['comp.out2'], np.ones(size) * 21., 1e-6)
 
             with self.assertRaises(Exception) as cm:
-                data = p.check_partials(out_stream=None)
+                data = p.check_partials(out_stream=None, step=1e-7)
             self.assertEquals(cm.exception.args[0],
                               "'comp' <class ExecComp>: expression contains functions ['unsafe'] that are not complex safe. To fix this, call declare_partials('*', ['z'], method='fd') on this component prior to setup.")
 
@@ -1654,10 +1697,10 @@ class TestFunctionRegistration(unittest.TestCase):
         prob.final_setup()
 
         # all subjac values should be size == size from above instead of (size, size)
-        self.assertEqual(comp1._subjacs_info[('comp1.x', 'comp1.t')]['value'].size, size)
-        self.assertEqual(comp2._subjacs_info[('comp2.y', 'comp2.t')]['value'].size, size)
-        self.assertEqual(comp3._subjacs_info[('comp3.z', 'comp3.t')]['value'].size, size)
-        self.assertEqual(comp4._subjacs_info[('comp4.w', 'comp4.t')]['value'].size, size)
+        self.assertEqual(comp1._subjacs_info[('comp1.x', 'comp1.t')]['val'].size, size)
+        self.assertEqual(comp2._subjacs_info[('comp2.y', 'comp2.t')]['val'].size, size)
+        self.assertEqual(comp3._subjacs_info[('comp3.z', 'comp3.t')]['val'].size, size)
+        self.assertEqual(comp4._subjacs_info[('comp4.w', 'comp4.t')]['val'].size, size)
 
     def test_register_err_keyword(self):
         with _temporary_expr_dict():
@@ -1759,7 +1802,7 @@ class TestExecCompParameterized(unittest.TestCase):
             for arg_name, arg_value in test_data['args'].items():
                 if arg_name == 'f':
                     continue
-                ivc.add_output(name=arg_name, val=arg_value['value'])
+                ivc.add_output(name=arg_name, val=arg_value['val'])
                 model.connect('ivc.{0}'.format(arg_name), 'comp.{0}'.format(arg_name))
 
         model.add_subsystem('comp', om.ExecComp(test_data['str'], **test_data['args']),
@@ -1781,11 +1824,11 @@ class TestExecCompParameterized(unittest.TestCase):
         if 'check_func' in test_data:
             check_args = []
             try:
-                check_args.append(test_data['args']['x']['value'])
+                check_args.append(test_data['args']['x']['val'])
             except Exception:
                 pass
             try:
-                check_args.append(test_data['args']['y']['value'])
+                check_args.append(test_data['args']['y']['val'])
             except Exception:
                 pass
             check_args = tuple(check_args)
@@ -1815,7 +1858,7 @@ class TestExecCompParameterized(unittest.TestCase):
             for arg_name, arg_value in test_data['args'].items():
                 if arg_name == 'f':
                     continue
-                ivc.add_output(name=arg_name, val=arg_value['value'])
+                ivc.add_output(name=arg_name, val=arg_value['val'])
                 model.connect('ivc.{0}'.format(arg_name),
                               '{0}_comp.{1}'.format(f, arg_name))
 
