@@ -4,7 +4,8 @@ import unittest
 import numpy as np
 
 import openmdao.api as om
-from openmdao.utils.assert_utils import assert_near_equal
+from openmdao.utils.assert_utils import assert_near_equal, assert_warning
+from openmdao.utils.om_warnings import OMDeprecationWarning
 
 
 class CompAddWithDefault(om.ExplicitComponent):
@@ -42,10 +43,15 @@ class CompAddWithIndices(om.ExplicitComponent):
 
     def setup(self):
         self.add_input('x_a', src_indices=0)
-        self.add_input('x_b', src_indices=(0, 1))
+        with assert_warning(OMDeprecationWarning, "<model> <class CompAddWithIndices>:"
+                            " When specifying src_indices for input 'x_b': 'src_indices=(0, 1)'"
+                            " is specified in a deprecated format. In a future release,"
+                            " 'src_indices' will be expected to use NumPy array indexing, "  
+                            "so replace the existing src_indices with [0, 1]."):
+            self.add_input('x_b', src_indices=(0, 1))
         self.add_input('x_c', src_indices=[0, 1])
         self.add_input('x_d', src_indices=np.arange(6))
-        self.add_input('x_e', src_indices=np.arange(6).reshape((3, 2)), shape=(3,2))
+        self.add_input('x_e', src_indices=np.arange(6).reshape((3, 2)), flat_src_indices=True)
 
         self.add_output('y')
 
@@ -54,10 +60,10 @@ class CompAddWithShapeAndIndices(om.ExplicitComponent):
     """Component for tests for declaring shape and array indices."""
 
     def setup(self):
-        self.add_input('x_a', shape=2, src_indices=(0,1))
-        self.add_input('x_b', shape=(2,), src_indices=(0,1))
-        self.add_input('x_c', shape=(2, 2), src_indices=np.arange(4).reshape((2, 2)))
-        self.add_input('x_d', shape=[2, 2], src_indices=np.arange(4).reshape((2, 2)))
+        self.add_input('x_a', shape=2, src_indices=[0, 1])
+        self.add_input('x_b', shape=(2,), src_indices=[0, 1])
+        self.add_input('x_c', shape=(2, 2), src_indices=np.arange(4).reshape((2, 2)), flat_src_indices=True)
+        self.add_input('x_d', shape=[2, 2], src_indices=np.arange(4).reshape((2, 2)), flat_src_indices=True)
 
 
 class CompAddArrayWithScalar(om.ExplicitComponent):
@@ -67,7 +73,7 @@ class CompAddArrayWithScalar(om.ExplicitComponent):
         self.add_input('x_a', val=2.0, shape=(6))
         self.add_input('x_b', val=2.0, shape=(3, 2))
         self.add_input('x_c', val=2.0, src_indices=np.arange(6))
-        self.add_input('x_d', val=2.0, src_indices=np.arange(6).reshape((3,2)), shape=(3,2))
+        self.add_input('x_d', val=2.0, src_indices=np.arange(6).reshape((3,2)), shape=(3,2), flat_src_indices=True)
 
         self.add_output('y_a', val=3.0, shape=(6))
         self.add_output('y_b', val=3.0, shape=(3, 2))
@@ -78,7 +84,8 @@ class CompAddWithArrayIndices(om.ExplicitComponent):
 
     def setup(self):
         self.add_input('x_a', val=2.0 * np.ones(6), src_indices=np.arange(6))
-        self.add_input('x_b', val=2.0 * np.ones((3, 2)), src_indices=np.arange(6).reshape((3, 2)))
+        self.add_input('x_b', val=2.0 * np.ones((3, 2)), src_indices=np.arange(6).reshape((3, 2)),
+                       flat_src_indices=True)
 
         self.add_output('y')
 
