@@ -57,11 +57,12 @@ class TestExplicitComponent(unittest.TestCase):
         with self.assertRaisesRegex(ValueError, msg):
             comp.add_input('arr', val=np.ones((2, 2)), shape=([2]))
 
-        msg = "Shape of indices does not match shape for '.*': Expected (.*) but got (.*)"
-
-        with self.assertRaisesRegex(ValueError, msg):
+        with self.assertRaises(ValueError) as cm:
             comp.add_input('arr', val=np.ones((2, 2)), src_indices=[0, 1])
 
+        msg = "Shape of indices (2,) does not match shape of (2, 2) for 'arr'."
+        self.assertEqual(str(cm.exception), msg)
+
         msg = ("The shape argument should be an int, tuple, or list "
                "but a '<(.*) 'numpy.ndarray'>' was given")
         with self.assertRaisesRegex(TypeError, msg):
@@ -92,7 +93,8 @@ class TestExplicitComponent(unittest.TestCase):
         with self.assertRaisesRegex(TypeError, msg):
             comp.add_output('x', val=val)
 
-        msg = 'The src_indices argument should be an int, list, tuple, ndarray or Iterable'
+        msg = "When specifying src_indices for input 'x': Can't create an index array " \
+              "using indices of non-integral type 'object_'."
         src = Component
 
         with self.assertRaisesRegex(TypeError, msg):
@@ -299,7 +301,7 @@ class TestExplicitComponent(unittest.TestCase):
         prob = Problem(comp).setup()
 
         # check optional metadata (desc)
-        msg = ("The metadata key 'value' will be deprecated in 4.0. Please use 'val'")
+        msg = ("The metadata key 'value' will be deprecated in 4.0. Please use 'val'.")
 
         prob.setup()
         with assert_warning(OMDeprecationWarning, msg):
@@ -310,7 +312,7 @@ class TestExplicitComponent(unittest.TestCase):
         idv = prob.model.add_subsystem('idv', IndepVarComp())
         meta = idv.add_output('x', 1.0)
 
-        msg = ("The metadata key 'value' will be deprecated in 4.0. Please use 'val'")
+        msg = ("The metadata key 'value' will be deprecated in 4.0. Please use 'val'.")
         with assert_warning(OMDeprecationWarning, msg):
             meta['value']
 
