@@ -14,7 +14,8 @@ from openmdao.test_suite.components.sellar import StateConnection, \
      SellarDis1withDerivatives, SellarDis2withDerivatives
 from openmdao.utils.assert_utils import assert_near_equal, assert_no_warning
 from openmdao.utils.general_utils import remove_whitespace
-from openmdao.warnings import OMDeprecationWarning
+from openmdao.utils.testing_utils import use_tempdirs
+from openmdao.utils.om_warnings import OMDeprecationWarning
 
 
 class ModCompEx(om.ExplicitComponent):
@@ -182,6 +183,7 @@ class ObjAdderCompEx(om.ExplicitComponent):
         discrete_outputs['y'].setval(discrete_inputs['x'].getval() + self.val.getval())
 
 
+@use_tempdirs
 class DiscreteTestCase(unittest.TestCase):
 
     def test_simple_run_once(self):
@@ -244,29 +246,30 @@ class DiscreteTestCase(unittest.TestCase):
         #
         # list vars before model has been run (relative names)
         #
+        # expl_inputs = prob.model.expl.list_inputs(values=True, out_stream=None)
         expl_inputs = prob.model.expl.list_inputs(out_stream=None)
         expected = {
-            'a': {'value': [10.]},
-            'x': {'value': 10}
+            'a': {'val': [10.]},
+            'x': {'val': 10}
         }
         self.assertEqual(dict(expl_inputs), expected)
 
         impl_inputs = prob.model.impl.list_inputs(out_stream=None)
         expected = {
-            'x': {'value': 10}
+            'x': {'val': 10}
         }
         self.assertEqual(dict(impl_inputs), expected)
 
         expl_outputs = prob.model.expl.list_outputs(out_stream=None)
         expected = {
-            'b': {'value': [0.]},
-            'y': {'value': 0}
+            'b': {'val': [0.]},
+            'y': {'val': 0}
         }
         self.assertEqual(dict(expl_outputs), expected)
 
         impl_outputs = prob.model.impl.list_outputs(out_stream=None)
         expected = {
-            'y': {'value': 0}
+            'y': {'val': 0}
         }
         self.assertEqual(dict(impl_outputs), expected)
 
@@ -353,7 +356,7 @@ class DiscreteTestCase(unittest.TestCase):
         expected = [
             "3 Input(s) in 'model'",
             "",
-            "varname  value  prom_name",
+            "varname  val  prom_name",
             "-------  -----  ---------",
             "expl.a   [10.]  expl.a",
             "expl.x   11     x",
@@ -376,7 +379,7 @@ class DiscreteTestCase(unittest.TestCase):
         expected = [
             "4 Explicit Output(s) in 'model'",
             "",
-            "varname  value  prom_name",
+            "varname  val    prom_name",
             "-------  -----  ---------",
             "_auto_ivc",
             "  v0    [10.]  _auto_ivc.v0",
@@ -388,7 +391,7 @@ class DiscreteTestCase(unittest.TestCase):
             "",
             "1 Implicit Output(s) in 'model'",
             "",
-            "varname  value  prom_name",
+            "varname  val    prom_name",
             "-------  -----  ---------",
             "impl",
             "  y    2      impl.y",
@@ -867,8 +870,6 @@ class DiscretePromTestCase(unittest.TestCase):
 class DiscreteFeatureTestCase(unittest.TestCase):
 
     def test_feature_discrete(self):
-        import numpy as np
-        import openmdao.api as om
 
         class BladeSolidity(om.ExplicitComponent):
             def setup(self):
@@ -909,7 +910,6 @@ class DiscreteFeatureTestCase(unittest.TestCase):
         assert_near_equal(prob['SolidityComp.blade_solidity'], 0.02984155, 1e-4)
 
     def test_feature_discrete_implicit(self):
-        import openmdao.api as om
 
         class ImpWithInitial(om.ImplicitComponent):
             """
