@@ -163,7 +163,7 @@ class MPITests2(unittest.TestCase):
                                                    x=np.zeros((9, 3)),
                                                    y=np.zeros((9, 3))))
         prob.model.connect('indep.x', 'comp.invec')
-        prob.model.connect('comp.outvec', 'total.x', src_indices=om.slicer[:])
+        prob.model.connect('comp.outvec', 'total.x', src_indices=om.slicer[:], flat_src_indices=True)
 
         prob.setup(check=False, mode='fwd')
         prob.run_model()
@@ -1131,7 +1131,8 @@ class MPITestsBug(unittest.TestCase):
                 end = start + sizes[rank]
 
                 self.add_input('x1', val=np.ones(sizes[rank]), distributed=True,
-                               src_indices=np.arange(start, end, dtype=int))
+                               src_indices=np.arange(start, end, dtype=int),
+                               flat_src_indices=True)
 
                 self.add_output('x0dot', val=np.ones(sizes[rank]), distributed=True)
 
@@ -1336,6 +1337,9 @@ class ZeroLengthInputsOutputs(unittest.TestCase):
         assert_near_equal(J[('C2.outvec', 'indep.x')],
                           np.eye(3)*np.append(2*np.ones(1), -3*np.ones(2)))
 
+        # Make sure that the code for handling element stepsize also works on a distributed model.
+        assert(prob.check_partials(step_calc='rel_element'))
+
 
 class DistribCompDenseJac(om.ExplicitComponent):
 
@@ -1636,8 +1640,6 @@ class TestDistribBugs(unittest.TestCase):
             model.connect('D1.out_dist', 'D2.in_dist')
             model.connect('D1.out_serial', 'D2.in_serial')
 
-        om.wing_dbg()
-
         prob = om.Problem(model)
         prob.setup(mode=mode, force_alloc_complex=True)
 
