@@ -1,5 +1,3 @@
-import os
-
 import unittest
 import numpy as np
 from io import StringIO
@@ -12,6 +10,7 @@ from openmdao.utils.mpi import MPI, multi_proc_exception_check
 from openmdao.utils.array_utils import evenly_distrib_idxs
 from openmdao.utils.assert_utils import assert_near_equal
 from openmdao.utils.general_utils import printoptions, remove_whitespace
+from openmdao.utils.testing_utils import use_tempdirs
 
 from openmdao.test_suite.groups.parallel_groups import FanOutGrouped
 from openmdao.test_suite.components.distributed_components import DistribComp, Summer
@@ -28,8 +27,6 @@ class DistributedAdder(om.ExplicitComponent):
     """
 
     def initialize(self):
-        self.options['distributed'] = True
-
         self.options.declare('size', types=int, default=1,
                              desc="Size of input and output vectors.")
 
@@ -50,9 +47,9 @@ class DistributedAdder(om.ExplicitComponent):
         start = local_offset
         end = local_offset + local_size
 
-        self.add_input('x', val=np.zeros(local_size, float),
+        self.add_input('x', val=np.zeros(local_size, float), distributed=True,
                        src_indices=np.arange(start, end, dtype=int))
-        self.add_output('y', val=np.zeros(local_size, float))
+        self.add_output('y', val=np.zeros(local_size, float), distributed=True)
 
     def compute(self, inputs, outputs):
 
@@ -62,6 +59,7 @@ class DistributedAdder(om.ExplicitComponent):
         outputs['y'] = inputs['x'] + 10.
 
 
+@use_tempdirs
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class DistributedListVarsTest(unittest.TestCase):
 
@@ -92,14 +90,14 @@ class DistributedListVarsTest(unittest.TestCase):
             else:
                 self.assertEqual(inputs[0][0], 'plus.x')
                 self.assertEqual(inputs[1][0], 'summer.invec')
-                self.assertEqual(inputs[0][1]['value'].size, 100)
-                self.assertEqual(inputs[1][1]['value'].size, 100)
+                self.assertEqual(inputs[0][1]['val'].size, 100)
+                self.assertEqual(inputs[1][1]['val'].size, 100)
 
             text = stream.getvalue()
             if prob.comm.rank:  # Only rank 0 prints
                 self.assertEqual(len(text), 0)
             else:
-                self.assertEqual(text.count('value'), 3)
+                self.assertEqual(text.count('val'), 3)
                 self.assertEqual(text.count('\nplus'), 1)
                 self.assertEqual(text.count('\n  x'), 1)
                 self.assertEqual(text.count('\nsummer'), 1)
@@ -125,15 +123,15 @@ class DistributedListVarsTest(unittest.TestCase):
                 self.assertEqual(outputs[0][0], 'des_vars.x')
                 self.assertEqual(outputs[1][0], 'plus.y')
                 self.assertEqual(outputs[2][0], 'summer.sum')
-                self.assertEqual(outputs[0][1]['value'].size, 100)
-                self.assertEqual(outputs[1][1]['value'].size, 100)
-                self.assertEqual(outputs[2][1]['value'].size, 1)
+                self.assertEqual(outputs[0][1]['val'].size, 100)
+                self.assertEqual(outputs[1][1]['val'].size, 100)
+                self.assertEqual(outputs[2][1]['val'].size, 1)
 
             text = stream.getvalue()
             if prob.comm.rank:  # Only rank 0 prints
                 self.assertEqual(len(text), 0)
             else:
-                self.assertEqual(text.count('value'), 3)
+                self.assertEqual(text.count('val'), 3)
                 self.assertEqual(text.count('\ndes_vars'), 1)
                 self.assertEqual(text.count('\n  x'), 1)
                 self.assertEqual(text.count('\nplus'), 1)
@@ -197,14 +195,14 @@ class DistributedListVarsTest(unittest.TestCase):
             else:
                 inames = [t[0] for t in inputs]
                 self.assertEqual(inames, ['Obj.y1', 'Obj.y2', 'par.G1.Cc.x', 'par.G1.Cy.x', 'par.G2.Cc.x', 'par.G2.Cy.x'])
-                self.assertTrue('value' in inputs[0][1])
+                self.assertTrue('val' in inputs[0][1])
 
             text = stream.getvalue()
             if prob.comm.rank:  # Only rank 0 prints
                 self.assertEqual(len(text), 0)
             else:
                 self.assertEqual(1, text.count("6 Input(s) in 'model'"), 1)
-                self.assertEqual(1, text.count('value'))
+                self.assertEqual(1, text.count('val'))
                 self.assertEqual(1, text.count('par'))
                 self.assertEqual(1, text.count('  G1'))
                 self.assertEqual(1, text.count('  G2'))
@@ -229,7 +227,7 @@ class DistributedListVarsTest(unittest.TestCase):
             onames = [t[0] for t in outputs]
             if prob.comm.rank == 0:
                 self.assertEqual(onames, ['Obj.obj', 'par.G1.Cc.c', 'par.G1.Cy.y', 'par.G1.indep_var_comp.x', 'par.G2.Cc.c', 'par.G2.Cy.y', 'par.G2.indep_var_comp.x'])
-                self.assertTrue('value' in outputs[0][1])
+                self.assertTrue('val' in outputs[0][1])
                 self.assertTrue('units' in outputs[0][1])
             else:
                 self.assertEqual(onames, [])
@@ -239,7 +237,7 @@ class DistributedListVarsTest(unittest.TestCase):
                 self.assertEqual(len(text), 0)
             else:
                 self.assertEqual(1, text.count("7 Explicit Output(s) in 'model'"))
-                self.assertEqual(1, text.count('value'))
+                self.assertEqual(1, text.count('val'))
                 self.assertEqual(1, text.count('units'))
                 self.assertEqual(1, text.count('par'))
                 self.assertEqual(1, text.count('  G1'))
@@ -282,7 +280,7 @@ class DistributedListVarsTest(unittest.TestCase):
                 expected = [
                     "6 Input(s) in 'model'",
                     '',
-                    'varname   value',
+                    'varname   val',
                     '--------  -----',
                     'c1.x',
                     'sub.c2.x',
@@ -311,7 +309,7 @@ class DistributedListVarsTest(unittest.TestCase):
                 expected = [
                     "6 Input(s) in 'model'",
                     '',
-                    'varname  value',
+                    'varname  val',
                     '-------  -----',
                     'c1',
                     '  x',
@@ -347,8 +345,8 @@ class DistributedListVarsTest(unittest.TestCase):
                 expected = [
                     "7 Explicit Output(s) in 'model'",
                     '',
-                    'varname   value   resids',
-                    '--------  -----   ------',
+                    'varname   val     resids',
+                    '--------  ----    ------',
                     'iv.x',
                     'c1.y',
                     'sub.c2.y',
@@ -380,7 +378,7 @@ class DistributedListVarsTest(unittest.TestCase):
                 expected = [
                     "7 Explicit Output(s) in 'model'",
                     '',
-                    'varname  value   resids',
+                    'varname  val     resids',
                     '-------  -----   ------',
                     'iv',
                     '  x',
@@ -439,10 +437,10 @@ class DistributedListVarsTest(unittest.TestCase):
             expected = [
                 "1 Input(s) in 'C2'",
                 '',
-                'varname  value            shape  global_shape',
+                'varname  val              shape  global_shape',
                 '-------  ---------------  -----  ------------',
                 'invec    |3.87298334621|  (8,)   (15,)',
-                '         value:',
+                '         val:',
                 '         array([ 1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.])'
             ]
 
@@ -462,10 +460,10 @@ class DistributedListVarsTest(unittest.TestCase):
             expected = [
                 "1 Explicit Output(s) in 'C2'",
                 '',
-                'varname  value            shape  global_shape',
+                'varname  val              shape  global_shape',
                 '-------  ---------------  -----  ------------',
                 'outvec   |3.87298334621|  (8,)   (15,)',
-                '         value:',
+                '         val:',
                 '         array([ 1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.,  1.])'
             ]
 
@@ -491,10 +489,10 @@ class DistributedListVarsTest(unittest.TestCase):
             expected = [
                 "1 Input(s) in 'C2'",
                 '',
-                'varname  value            shape  global_shape',
+                'varname  val              shape  global_shape',
                 '-------  ---------------  -----  ------------',
                 'invec    |3.87298334621|  (8,)   (15,)',
-                '         value:',
+                '         val:',
                 '         array([1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.])'
             ]
             for i, line in enumerate(expected):
@@ -513,10 +511,10 @@ class DistributedListVarsTest(unittest.TestCase):
             expected = [
                 "1 Explicit Output(s) in 'C2'",
                 '',
-                'varname  value           shape  global_shape',
+                'varname  val             shape  global_shape',
                 '-------  --------------  -----  ------------',
                 'outvec   |9.74679434481|  (8,)   (15,)',
-                '         value:',
+                '         val:',
                 '         array([ 2.,  2.,  2.,  2.,  2.,  2.,  2.,  2., -3., -3., -3., -3., -3., -3., -3.])'
             ]
             for i, line in enumerate(expected):
@@ -540,10 +538,10 @@ class DistributedListVarsTest(unittest.TestCase):
         expected = [
             "1 Input(s) in 'C3'",
             '',
-            'varname  value                shape  global_shape',
+            'varname  val                  shape  global_shape',
             '-------  -------------------  -----  ------------',
             'invec  {}  {}   {}        '.format(norm, shape, shape),
-            '         value:',
+            '         val:',
             '         array({})'.format(value),
         ]
 
@@ -555,6 +553,7 @@ class DistributedListVarsTest(unittest.TestCase):
         assert_near_equal(prob['C3.sum'], -5.)
 
 
+@use_tempdirs
 @unittest.skipUnless(PETScVector, "PETSc is required.")
 @unittest.skipUnless(MPI, "MPI is required.")
 class MPIFeatureTests(unittest.TestCase):
@@ -562,9 +561,6 @@ class MPIFeatureTests(unittest.TestCase):
     N_PROCS = 2
 
     def test_distribcomp_list_feature(self):
-        import numpy as np
-        import openmdao.api as om
-        from openmdao.test_suite.components.distributed_components import DistribComp, Summer
 
         size = 15
 
