@@ -9,12 +9,12 @@ import numpy as np
 
 import openmdao.api as om
 from openmdao.core.driver import Driver
+from openmdao.test_suite.components.paraboloid import Paraboloid
+from openmdao.test_suite.components.sellar import SellarDerivatives, SellarDerivativesConnected
 from openmdao.utils.assert_utils import assert_near_equal, assert_warning
 import openmdao.utils.hooks as hooks
-from openmdao.test_suite.components.paraboloid import Paraboloid
-from openmdao.test_suite.components.sellar import SellarDerivatives
 from openmdao.utils.units import convert_units
-from openmdao.warnings import DerivativesWarning
+from openmdao.utils.om_warnings import DerivativesWarning
 
 try:
     from parameterized import parameterized
@@ -142,8 +142,6 @@ class TestProblem(unittest.TestCase):
         self.assertEqual(p.get_val('bar'), lbf_val)
 
     def test_feature_simple_run_once_no_promote(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
         model = prob.model
@@ -159,8 +157,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob['comp.f_xy'], -15.0)
 
     def test_feature_simple_run_once_input_input(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
         model = prob.model
@@ -178,8 +174,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob['comp2.f_xy'], 13.0)
 
     def test_feature_simple_run_once_compute_totals(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
         model = prob.model
@@ -202,8 +196,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(totals['comp.f_xy']['comp.y'][0][0], 3.0)
 
     def test_feature_simple_run_once_compute_totals_scaled(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
         model = prob.model
@@ -226,8 +218,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(totals[('comp.f_xy', 'comp.y')][0][0], 3.0)
 
     def test_feature_simple_run_once_set_deriv_mode(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
         model = prob.model
@@ -312,9 +302,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(J[('MP1.y', 'indeps2.x')], np.zeros((5, 3)), 1e-10)
 
     def test_set_2d_array(self):
-        import numpy as np
-
-        import openmdao.api as om
 
         prob = om.Problem()
         model = prob.model
@@ -574,8 +561,6 @@ class TestProblem(unittest.TestCase):
         np.testing.assert_allclose(checkvec, result)
 
     def test_feature_set_indeps(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
 
@@ -592,8 +577,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob['f_xy'], 214.0, 1e-6)
 
     def test_feature_set_indeps_auto(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
 
@@ -607,8 +590,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('f_xy'), 214.0, 1e-6)
 
     def test_feature_basic_setup(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
         model = prob.model
@@ -635,8 +616,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('f_xy'), 174.0, 1e-6)
 
     def test_feature_petsc_setup(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.paraboloid import Paraboloid
 
         prob = om.Problem()
         model = prob.model
@@ -653,8 +632,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob['f_xy'], 214.0, 1e-6)
 
     def test_feature_check_totals_manual(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -667,8 +644,6 @@ class TestProblem(unittest.TestCase):
         prob.check_totals(of=['obj', 'con1'], wrt=['x', 'z'])
 
     def test_feature_check_totals_from_driver_compact(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -690,8 +665,6 @@ class TestProblem(unittest.TestCase):
         prob.check_totals(compact_print=True)
 
     def test_feature_check_totals_from_driver(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -713,8 +686,6 @@ class TestProblem(unittest.TestCase):
         prob.check_totals()
 
     def test_feature_check_totals_from_driver_scaled(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -736,8 +707,6 @@ class TestProblem(unittest.TestCase):
         prob.check_totals(driver_scaling=True)
 
     def test_feature_check_totals_suppress(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -760,8 +729,6 @@ class TestProblem(unittest.TestCase):
         print(totals)
 
     def test_feature_check_totals_cs(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -825,7 +792,6 @@ class TestProblem(unittest.TestCase):
                          msg="The under_complex_step flag should be reset.")
 
     def test_feature_check_totals_user_detect_forced(self):
-        import openmdao.api as om
 
         class SimpleComp(om.ExplicitComponent):
 
@@ -877,10 +843,6 @@ class TestProblem(unittest.TestCase):
         self.assertEqual(cm.exception.args[0], msg)
 
     def test_feature_run_driver(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem(model=SellarDerivatives())
         model = prob.model
@@ -906,8 +868,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('obj'), 3.18339395, 1e-2)
 
     def test_feature_promoted_sellar_set_get_outputs(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem(model=SellarDerivatives())
         prob.model.nonlinear_solver = om.NonlinearBlockGS()
@@ -921,8 +881,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('y1'), 27.3049178437, 1e-6)
 
     def test_feature_not_promoted_sellar_set_get_outputs(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivativesConnected
 
         prob = om.Problem(model= SellarDerivativesConnected())
         prob.model.nonlinear_solver = om.NonlinearBlockGS()
@@ -938,8 +896,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('d1.y1'), 27.3049178437, 1e-6)
 
     def test_feature_promoted_sellar_set_get_inputs(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem(model=SellarDerivatives())
         prob.model.nonlinear_solver = om.NonlinearBlockGS()
@@ -958,22 +914,21 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob['d2.y1'], 27.3049178437, 1e-6)
 
     def test_get_set_with_units_exhaustive(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         prob.model.add_subsystem('comp', om.ExecComp('y=x-25.',
-                                                     x={'value': 77.0, 'units': 'degF'},
-                                                     y={'value': 0.0, 'units': 'degC'}))
+                                                     x={'val': 77.0, 'units': 'degF'},
+                                                     y={'val': 0.0, 'units': 'degC'}))
         prob.model.add_subsystem('prom', om.ExecComp('yy=xx-25.',
-                                                     xx={'value': 77.0, 'units': 'degF'},
-                                                     yy={'value': 0.0, 'units': 'degC'}),
+                                                     xx={'val': 77.0, 'units': 'degF'},
+                                                     yy={'val': 0.0, 'units': 'degC'}),
                                  promotes=['xx', 'yy'])
         prob.model.add_subsystem('acomp', om.ExecComp('y=x-25.',
-                                                      x={'value': np.array([77.0, 95.0]), 'units': 'degF'},
-                                                      y={'value': 0.0, 'units': 'degC'}))
+                                                      x={'val': np.array([77.0, 95.0]), 'units': 'degF'},
+                                                      y={'val': 0.0, 'units': 'degC'}))
         prob.model.add_subsystem('aprom', om.ExecComp('ayy=axx-25.',
-                                                      axx={'value': np.array([77.0, 95.0]), 'units': 'degF'},
-                                                      ayy={'value': 0.0, 'units': 'degC'}),
+                                                      axx={'val': np.array([77.0, 95.0]), 'units': 'degF'},
+                                                      ayy={'val': 0.0, 'units': 'degC'}),
                                  promotes=['axx', 'ayy'])
 
         prob.setup()
@@ -1073,37 +1028,35 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('axx', 'degC', indices=np.array([0])), 35.0, 1e-6)
 
     def test_feature_get_set_with_units_diff_err(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         prob.model.add_subsystem('C1', om.ExecComp('y=x*2.',
-                                                     x={'value': 1.0, 'units': 'ft'},
-                                                     y={'value': 0.0, 'units': 'ft'}),
+                                                     x={'val': 1.0, 'units': 'ft'},
+                                                     y={'val': 0.0, 'units': 'ft'}),
                                  promotes=['x'])
         prob.model.add_subsystem('C2', om.ExecComp('y=x*3.',
-                                                     x={'value': 1.0, 'units': 'inch'},
-                                                     y={'value': 0.0, 'units': 'inch'}),
+                                                     x={'val': 1.0, 'units': 'inch'},
+                                                     y={'val': 0.0, 'units': 'inch'}),
                                  promotes=['x'])
 
         try:
             prob.setup()
         except RuntimeError as err:
-            self.assertEqual(str(err), "<model> <class Group>: The following inputs, ['C1.x', 'C2.x'], promoted to 'x', are connected but their metadata entries ['units', 'value'] differ. Call <group>.set_input_defaults('x', units=?, val=?), where <group> is the model to remove the ambiguity.")
+            self.assertEqual(str(err), "<model> <class Group>: The following inputs, ['C1.x', 'C2.x'], promoted to 'x', are connected but their metadata entries ['units', 'val'] differ. Call <group>.set_input_defaults('x', units=?, val=?), where <group> is the model to remove the ambiguity.")
         else:
             self.fail("Exception expected.")
 
     def test_feature_get_set_with_units_diff(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         G1 = prob.model.add_subsystem('G1', om.Group())
         G1.add_subsystem('C1', om.ExecComp('y=x*2.',
-                                            x={'value': 1.0, 'units': 'cm'},
-                                            y={'value': 0.0, 'units': 'cm'}),
+                                            x={'val': 1.0, 'units': 'cm'},
+                                            y={'val': 0.0, 'units': 'cm'}),
                          promotes=['x'])
         G1.add_subsystem('C2', om.ExecComp('y=x*3.',
-                                            x={'value': 1.0, 'units': 'mm'},
-                                            y={'value': 0.0, 'units': 'mm'}),
+                                            x={'val': 1.0, 'units': 'mm'},
+                                            y={'val': 0.0, 'units': 'mm'}),
                          promotes=['x'])
 
         # units and value to use for the _auto_ivc output are ambiguous.  This fixes that.
@@ -1126,21 +1079,20 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('G1.C2.x'), 2000.0, 1e-6)
 
     def test_feature_get_set_with_src_indices_diff(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         G1 = prob.model.add_subsystem('G1', om.Group())
         G1.add_subsystem('C1', om.ExecComp('y=x*2.',
-                                            x={'value': 1.0, 'units': 'cm', 'src_indices': [0]},
-                                            y={'value': 0.0, 'units': 'cm'}),
+                                            x={'val': 1.0, 'units': 'cm', 'src_indices': [0]},
+                                            y={'val': 0.0, 'units': 'cm'}),
                          promotes=['x'])
         G1.add_subsystem('C2', om.ExecComp('y=x*3.',
-                                            x={'value': 1.0, 'units': 'mm', 'src_indices': [1,2]},
-                                            y={'value': np.zeros(2), 'units': 'mm'}),
+                                            x={'val': 1.0, 'units': 'mm', 'src_indices': [1,2]},
+                                            y={'val': np.zeros(2), 'units': 'mm'}),
                          promotes=['x'])
         G1.add_subsystem('C3', om.ExecComp('y=x*4.',
-                                            x={'value': np.ones(3), 'units': 'mm'},
-                                            y={'value': np.zeros(3), 'units': 'mm'}),
+                                            x={'val': np.ones(3), 'units': 'mm'},
+                                            y={'val': np.zeros(3), 'units': 'mm'}),
                          promotes=['x'])
 
         # units and value to use for the _auto_ivc output are ambiguous.  This fixes that.
@@ -1167,18 +1119,17 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob['G1.C2.y'], np.ones(2) * 6000.0, 1e-6)
 
     def test_feature_get_set_with_units_prom_plus_explicit(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         prob.model.add_subsystem('indeps', om.IndepVarComp('x', val=1.0, units='m'))
         G1 = prob.model.add_subsystem('G1', om.Group())
         G1.add_subsystem('C1', om.ExecComp('y=x*2.',
-                                            x={'value': 1.0, 'units': 'cm'},
-                                            y={'value': 0.0, 'units': 'cm'}),
+                                            x={'val': 1.0, 'units': 'cm'},
+                                            y={'val': 0.0, 'units': 'cm'}),
                          promotes=['x'])
         G1.add_subsystem('C2', om.ExecComp('y=x*3.',
-                                            x={'value': 1.0, 'units': 'mm'},
-                                            y={'value': 0.0, 'units': 'mm'}),
+                                            x={'val': 1.0, 'units': 'mm'},
+                                            y={'val': 0.0, 'units': 'mm'}),
                          promotes=['x'])
 
         # connect IVC to promoted inputs
@@ -1209,18 +1160,17 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob['G1.C2.x'], 2000.0, 1e-6)
 
     def test_feature_get_set_with_units_prom_plus_explicit_err(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         prob.model.add_subsystem('indeps', om.IndepVarComp('x', val=1.0, units='m'))
         G1 = prob.model.add_subsystem('G1', om.Group())
         G1.add_subsystem('C1', om.ExecComp('y=x*2.',
-                                            x={'value': 1.0, 'units': 'cm'},
-                                            y={'value': 0.0, 'units': 'cm'}),
+                                            x={'val': 1.0, 'units': 'cm'},
+                                            y={'val': 0.0, 'units': 'cm'}),
                          promotes=['x'])
         G1.add_subsystem('C2', om.ExecComp('y=x*3.',
-                                            x={'value': 1.0, 'units': 'mm'},
-                                            y={'value': 0.0, 'units': 'mm'}),
+                                            x={'val': 1.0, 'units': 'mm'},
+                                            y={'val': 0.0, 'units': 'mm'}),
                          promotes=['x'])
 
         # connect IVC to promoted inputs
@@ -1249,13 +1199,12 @@ class TestProblem(unittest.TestCase):
         self.assertEqual(cm.exception.args[0], msg)
 
     def test_get_set_with_units_error_messages(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         prob.model.add_subsystem('comp', om.ExecComp('y=x+1.',
-                                                     x={'value': 100.0, 'units': 'cm'},
+                                                     x={'val': 100.0, 'units': 'cm'},
                                                      y={'units': 'm'}))
-        prob.model.add_subsystem('no_unit', om.ExecComp('y=x+1.', x={'value': 100.0}))
+        prob.model.add_subsystem('no_unit', om.ExecComp('y=x+1.', x={'val': 100.0}))
 
         prob.setup()
         prob.run_model()
@@ -1275,11 +1224,10 @@ class TestProblem(unittest.TestCase):
             prob.set_val('no_unit.x', 55.0, 'degK')
 
     def test_feature_get_set_with_units(self):
-        import openmdao.api as om
 
         prob = om.Problem()
         prob.model.add_subsystem('comp', om.ExecComp('y=x+1.',
-                                                     x={'value': 100.0, 'units': 'cm'},
+                                                     x={'val': 100.0, 'units': 'cm'},
                                                      y={'units': 'm'}))
 
         prob.setup()
@@ -1292,12 +1240,10 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('comp.x', 'm'), 1.0e-2, 1e-6)
 
     def test_feature_get_set_array_with_units(self):
-        import numpy as np
-        import openmdao.api as om
 
         prob = om.Problem()
         prob.model.add_subsystem('comp', om.ExecComp('y=x+1.',
-                                                     x={'value': np.array([100.0, 33.3]), 'units': 'cm'},
+                                                     x={'val': np.array([100.0, 33.3]), 'units': 'cm'},
                                                      y={'shape': (2, ), 'units': 'm'}))
 
         prob.setup()
@@ -1316,12 +1262,10 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('comp.x', 'm', indices=1), 5.0e-2, 1e-6)
 
     def test_feature_get_set_array_with_slicer(self):
-        import numpy as np
-        import openmdao.api as om
 
         prob = om.Problem()
         prob.model.add_subsystem('comp', om.ExecComp('y=x+1.',
-                                                     x={'value': np.array([[1., 2.], [3., 4.]]), },
+                                                     x={'val': np.array([[1., 2.], [3., 4.]]), },
                                                      y={'shape': (2, 2), }))
 
         prob.setup()
@@ -1337,10 +1281,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('comp.y', indices=om.slicer[:, 0]), [6., 7.], 1e-6)
 
     def test_feature_set_get_array(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem(model=SellarDerivatives())
         prob.model.nonlinear_solver = om.NonlinearBlockGS()
@@ -1371,8 +1311,6 @@ class TestProblem(unittest.TestCase):
         assert_near_equal(prob.get_val('y2'), 8.14191301549, 1e-6)
 
     def test_feature_residuals(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem(model=SellarDerivatives())
         prob.model.nonlinear_solver = om.NonlinearBlockGS()
@@ -1552,8 +1490,8 @@ class TestProblem(unittest.TestCase):
 
         p.setup(check=False, mode='rev')
 
-        relevant = model.get_relevant_vars(['indep1.x', 'indep2.x'],
-                                           ['C8.y', 'Unconnected.y'], mode='rev')
+        relevant = model.get_relevant_vars({'indep1.x': {}, 'indep2.x': {}},
+                                           {'C8.y': {}, 'Unconnected.y': {}}, mode='rev')
 
         indep1_ins = set(['C3.b', 'C3.c', 'C8.b', 'G1.C1.a', 'G2.C5.a', 'G2.C5.b'])
         indep1_outs = set(['C3.y', 'C8.y', 'G1.C1.z', 'G2.C5.x', 'indep1.x'])
@@ -1778,17 +1716,17 @@ class TestProblem(unittest.TestCase):
 
             inputs = p.model.list_inputs(out_stream=None)
             self.assertEqual(sorted(inputs), [
-                ('comp3.a', {'value': [2.]}),
-                ('comp3.b', {'value': [3.]})
+                ('comp3.a', {'val': [2.]}),
+                ('comp3.b', {'val': [3.]})
             ], "Inputs don't match when added in %s." % where)
 
             outputs = p.model.list_outputs(out_stream=None)
             self.assertEqual(sorted(outputs), [
-                ('comp1.a',   {'value': [2.]}),
-                ('comp1.foo', {'value': [1.]}),
-                ('comp2.b',   {'value': [3.]}),
-                ('comp2.foo', {'value': [1.]}),
-                ('comp3.y',   {'value': [5.]})
+                ('comp1.a',   {'val': [2.]}),
+                ('comp1.foo', {'val': [1.]}),
+                ('comp2.b',   {'val': [3.]}),
+                ('comp2.foo', {'val': [1.]}),
+                ('comp3.y',   {'val': [5.]})
             ], "Outputs don't match when added in %s." % where)
 
     def test_configure_add_input_output(self):
@@ -1834,15 +1772,15 @@ class TestProblem(unittest.TestCase):
 
         inputs = p.model.list_inputs(out_stream=None)
         self.assertEqual(sorted(inputs), [
-            ('mcomp.a',     {'value': [2.]}),
-            ('sub.mcomp.a', {'value': [2.]}),
+            ('mcomp.a',     {'val': [2.]}),
+            ('sub.mcomp.a', {'val': [2.]}),
         ])
 
         outputs = p.model.list_outputs(out_stream=None)
         self.assertEqual(sorted(outputs), [
-            ('indep.a',      {'value': [2.]}),
-            ('mcomp.a2',     {'value': [4.]}),
-            ('sub.mcomp.a2', {'value': [4.]}),
+            ('indep.a',      {'val': [2.]}),
+            ('mcomp.a2',     {'val': [4.]}),
+            ('sub.mcomp.a2', {'val': [4.]}),
         ])
 
         # add inputs/outputs in configure
@@ -1852,24 +1790,23 @@ class TestProblem(unittest.TestCase):
 
         inputs = p.model.list_inputs(out_stream=None)
         self.assertEqual(sorted(inputs), [
-            ('mcomp.a',     {'value': [2.]}),
-            ('mcomp.b',     {'value': [3.]}),
-            ('sub.mcomp.a', {'value': [2.]}),
-            ('sub.mcomp.b', {'value': [3.]}),
+            ('mcomp.a',     {'val': [2.]}),
+            ('mcomp.b',     {'val': [3.]}),
+            ('sub.mcomp.a', {'val': [2.]}),
+            ('sub.mcomp.b', {'val': [3.]}),
         ])
 
         outputs= p.model.list_outputs(out_stream=None)
         self.assertEqual(sorted(outputs), [
-            ('indep.a',      {'value': [2.]}),
-            ('indep.b',      {'value': [3.]}),
-            ('mcomp.a2',     {'value': [4.]}),
-            ('mcomp.b2',     {'value': [6.]}),
-            ('sub.mcomp.a2', {'value': [4.]}),
-            ('sub.mcomp.b2', {'value': [6.]}),
+            ('indep.a',      {'val': [2.]}),
+            ('indep.b',      {'val': [3.]}),
+            ('mcomp.a2',     {'val': [4.]}),
+            ('mcomp.b2',     {'val': [6.]}),
+            ('sub.mcomp.a2', {'val': [4.]}),
+            ('sub.mcomp.b2', {'val': [6.]}),
         ])
 
     def test_feature_post_setup_solver_configure(self):
-        import openmdao.api as om
 
         class ImplSimple(om.ImplicitComponent):
 
@@ -1996,29 +1933,26 @@ class TestProblem(unittest.TestCase):
                 desvar_opts=['lower', 'upper', 'ref', 'ref0',
                              'indices', 'adder', 'scaler',
                              'parallel_deriv_color',
-                             'vectorize_derivs',
                              'cache_linear_solution'],
                 cons_opts=['lower', 'upper', 'equals', 'ref', 'ref0',
                            'indices', 'adder', 'scaler', 'linear',
                            'parallel_deriv_color',
-                           'vectorize_derivs',
                            'cache_linear_solution'],
                 objs_opts=['ref', 'ref0',
                            'indices', 'adder', 'scaler',
                            'parallel_deriv_color',
-                           'vectorize_derivs',
                            'cache_linear_solution'],
             )
         finally:
             sys.stdout = stdout
         output = strout.getvalue().split('\n')
         self.assertRegex(output[3],
-                    r'^name\s+value\s+size\s+lower\s+upper\s+ref\s+ref0\s+'
+                    r'^name\s+val\s+size\s+lower\s+upper\s+ref\s+ref0\s+'
                     r'indices\s+adder\s+scaler\s+parallel_deriv_color\s+'
-                    r'vectorize_derivs\s+cache_linear_solution')
+                    r'cache_linear_solution')
         self.assertRegex(output[5],
                     r'^z\s+\|[0-9.e+-]+\|\s+2\s+\|10.0\|\s+\|[0-9.e+-]+\|\s+None\s+'
-                    r'None\s+None\s+None\s+None\s+None\s+False\s+False')
+                    r'None\s+None\s+None\s+None\s+None\s+False')
 
         # With all the optional columns and print_arrays
         stdout = sys.stdout
@@ -2029,23 +1963,20 @@ class TestProblem(unittest.TestCase):
                                    desvar_opts=['lower', 'upper', 'ref', 'ref0',
                                                 'indices', 'adder', 'scaler',
                                                 'parallel_deriv_color',
-                                                'vectorize_derivs',
                                                 'cache_linear_solution'],
                                    cons_opts=['lower', 'upper', 'equals', 'ref', 'ref0',
                                               'indices', 'adder', 'scaler', 'linear',
                                               'parallel_deriv_color',
-                                              'vectorize_derivs',
                                               'cache_linear_solution'],
                                    objs_opts=['ref', 'ref0',
                                               'indices', 'adder', 'scaler',
                                               'parallel_deriv_color',
-                                              'vectorize_derivs',
                                               'cache_linear_solution'],
                                    )
         finally:
             sys.stdout = stdout
         output = strout.getvalue().split('\n')
-        self.assertRegex(output[6], r'^\s+value:')
+        self.assertRegex(output[6], r'^\s+val:')
         self.assertRegex(output[7], r'^\s+array+\(+\[[0-9., e+-]+\]+\)')
         self.assertRegex(output[9], r'^\s+lower:')
         self.assertRegex(output[10], r'^\s+array+\(+\[[0-9., e+-]+\]+\)')
@@ -2102,9 +2033,6 @@ class TestProblem(unittest.TestCase):
         self.assertTrue('3.18' in output[21]) # obj
 
     def test_feature_list_problem_vars(self):
-        import numpy as np
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem(model=SellarDerivatives())
         model = prob.model
@@ -2126,14 +2054,12 @@ class TestProblem(unittest.TestCase):
         prob.list_problem_vars(print_arrays=True,
                                desvar_opts=['lower', 'upper', 'ref', 'ref0',
                                             'indices', 'adder', 'scaler',
-                                            'parallel_deriv_color',
-                                            'vectorize_derivs'],
+                                            'parallel_deriv_color'],
                                cons_opts=['lower', 'upper', 'equals', 'ref', 'ref0',
                                           'indices', 'adder', 'scaler', 'linear'],
                                objs_opts=['ref', 'ref0',
                                           'indices', 'adder', 'scaler',
                                           'parallel_deriv_color',
-                                          'vectorize_derivs',
                                           'cache_linear_solution'])
 
     def test_error_msg_set_val_before_setup(self):
