@@ -894,8 +894,6 @@ class TestScaling(unittest.TestCase):
         assert_near_equal(prob['comp.y'], 2.0)
 
     def test_feature1(self):
-        import openmdao.api as om
-        from openmdao.core.tests.test_scaling import ScalingExample1
 
         prob = om.Problem()
         model = prob.model
@@ -918,8 +916,6 @@ class TestScaling(unittest.TestCase):
             assert_near_equal(val, 6.0)
 
     def test_feature2(self):
-        import openmdao.api as om
-        from openmdao.core.tests.test_scaling import ScalingExample2
 
         prob = om.Problem()
         model = prob.model
@@ -942,8 +938,6 @@ class TestScaling(unittest.TestCase):
             assert_near_equal(val, 0.5)
 
     def test_feature3(self):
-        import openmdao.api as om
-        from openmdao.core.tests.test_scaling import ScalingExample3
 
         prob = om.Problem()
         model = prob.model
@@ -966,8 +960,6 @@ class TestScaling(unittest.TestCase):
             assert_near_equal(val, (1-6000.)/6000.)
 
     def test_feature_vector(self):
-        import openmdao.api as om
-        from openmdao.core.tests.test_scaling import ScalingExampleVector
 
         prob = om.Problem()
         model = prob.model
@@ -1006,6 +998,106 @@ class TestScaling(unittest.TestCase):
         assert_near_equal(p.model.sub1.sub2._inputs._scaling[0],
                           np.array([0, 32]), tolerance=1e-12)
 
+    def test_totals_with_solver_scaling(self):
+        ref = 1000.0
+
+        class Comp1(om.ExplicitComponent):
+
+            def initialize(self):
+                self.options.declare('units', None)
+
+            def setup(self):
+                self.add_input('a1')
+                self.add_input('a2')
+                self.add_output('b', units=self.options['units'], ref = ref)
+                self.declare_partials('*', '*')
+
+            def compute(self, inputs, outputs):
+                a1 = inputs['a1']
+                a2 = inputs['a2']
+                b = 2*a1*a2
+                outputs['b'] = b
+
+            def compute_partials(self, inputs, partials):
+                a1 = inputs['a1']
+                a2 = inputs['a2']
+                partials['b', 'a1'] = 2*a2
+                partials['b', 'a2'] = 2*a1
+
+
+        class Comp2(om.ExplicitComponent):
+
+            def initialize(self):
+                self.options.declare('units', None)
+
+            def setup(self):
+                self.add_input('b', units=self.options['units'])
+                self.add_output('c')
+                self.declare_partials(['c'], ['b'])
+
+            def compute(self, inputs, outputs):
+                b = inputs['b']
+                c = 2*b
+                outputs['c'] = c
+
+            def compute_partials(self, inputs, partials):
+                partials['c', 'b'] = 2
+
+        model = om.Group()
+        model.add_subsystem('comp_1', Comp1(), promotes = ['*'])
+        model.add_subsystem('comp_2', Comp2(), promotes = ['*'])
+
+        model.add_design_var('a1', lower = 0.5, upper = 1.5)
+        model.add_design_var('a2', lower = 0.5, upper = 1.5)
+
+        model.set_input_defaults('a1', val = 1.)
+        model.set_input_defaults('a2', val = 1.)
+
+        model.add_objective('c')
+
+        problem = om.Problem()
+        problem.model = model
+
+        problem.driver = om.ScipyOptimizeDriver()
+        problem.driver.options['optimizer'] = 'SLSQP'
+
+        problem.setup(mode='rev')
+        problem.set_solver_print(level=0)
+        problem.run_model()
+
+        totals = problem.check_totals(out_stream=None)
+        assert_near_equal(totals['comp_2.c', 'a1']['abs error'][0], 0.0, tolerance=1e-7)
+        assert_near_equal(totals['comp_2.c', 'a2']['abs error'][0], 0.0, tolerance=1e-7)
+
+        # Now, include unit conversion
+
+        model = om.Group()
+        model.add_subsystem('comp_1', Comp1(units='degC'), promotes = ['*'])
+        model.add_subsystem('comp_2', Comp2(units='degF'), promotes = ['*'])
+
+        model.add_design_var('a1', lower = 0.5, upper = 1.5)
+        model.add_design_var('a2', lower = 0.5, upper = 1.5)
+
+        model.set_input_defaults('a1', val = 1.)
+        model.set_input_defaults('a2', val = 1.)
+
+        model.add_objective('c')
+
+        problem = om.Problem()
+        problem.model = model
+
+        problem.driver = om.ScipyOptimizeDriver()
+        problem.driver.options['optimizer'] = 'SLSQP'
+
+        problem.setup(mode='rev')
+        problem.set_solver_print(level=0)
+        problem.run_model()
+
+        totals = problem.check_totals(out_stream=None)
+        assert_near_equal(totals['comp_2.c', 'a1']['abs error'][0], 0.0, tolerance=1e-7)
+        assert_near_equal(totals['comp_2.c', 'a2']['abs error'][0], 0.0, tolerance=1e-7)
+
+
 class MyComp(om.ExplicitComponent):
 
     def setup(self):
@@ -1382,5 +1474,40 @@ class TestDriverScalingReport(unittest.TestCase):
         data = p.driver.scaling_report(show_browser=False)
         self._check_data(data, expected)
 
+    def test_unconstrained(self):
+        from openmdao.test_suite.components.paraboloid import Paraboloid
+
+        # build the model
+        prob = om.Problem()
+        indeps = prob.model.add_subsystem('indeps', om.IndepVarComp())
+        indeps.add_output('x', 3.0)
+        indeps.add_output('y', -4.0)
+
+        prob.model.add_subsystem('paraboloid', Paraboloid())
+
+        prob.model.connect('indeps.x', 'paraboloid.x')
+        prob.model.connect('indeps.y', 'paraboloid.y')
+
+        # setup the optimization
+        prob.driver = om.ScipyOptimizeDriver()
+        prob.driver.options['optimizer'] = 'COBYLA'
+
+        prob.model.add_design_var('indeps.x', lower=-50, upper=50)
+        prob.model.add_design_var('indeps.y', lower=-50, upper=50)
+        prob.model.add_objective('paraboloid.f_xy', index=0)
+
+        prob.setup()
+        prob.run_driver()
+
+        # minimum value
+        assert_near_equal(prob['paraboloid.f_xy'], -27.33333, 1e-6)
+
+        # location of the minimum
+        assert_near_equal(prob['indeps.x'], 6.6667, 1e-4)
+        assert_near_equal(prob['indeps.y'], -7.33333, 1e-4)
+
+        # just make sure this doesn't raise an exception
+        prob.driver.scaling_report(show_browser=False)
+
 if __name__ == '__main__':
     unittest.main()
