@@ -13,6 +13,11 @@ class NonlinearRunOnce(NonlinearSolver):
     Simple solver that runs the containing system once.
 
     This is done without iteration or norm calculation.
+
+    Parameters
+    ----------
+    **kwargs : dict
+        Options dictionary.
     """
 
     SOLVER = 'NL: RUNONCE'
@@ -32,8 +37,6 @@ class NonlinearRunOnce(NonlinearSolver):
                     for subsys in system._subsystems_myproc:
                         subsys._solve_nonlinear()
 
-                system._check_child_reconf()
-
             # If this is not a parallel group, transfer for each subsystem just prior to running it.
             else:
                 self._gs_iter()
