@@ -9,10 +9,6 @@ import openmdao.api as om
 class TestKeplersEquation(unittest.TestCase):
 
     def test_result(self):
-        import numpy as np
-        from numpy.testing import assert_almost_equal
-
-        import openmdao.api as om
 
         prob = om.Problem()
 
@@ -29,9 +25,9 @@ class TestKeplersEquation(unittest.TestCase):
 
         # ExecComp used to compute the LHS of Kepler's equation.
         lhs_comp = om.ExecComp('lhs=E - ecc * sin(E)',
-                               lhs={'value': 0.0, 'units': 'rad'},
-                               E={'value': 0.0, 'units': 'rad'},
-                               ecc={'value': 0.0})
+                               lhs={'val': 0.0, 'units': 'rad'},
+                               E={'val': 0.0, 'units': 'rad'},
+                               ecc={'val': 0.0})
 
         prob.model.add_subsystem(name='balance', subsys=bal,
                                  promotes_inputs=['M'],
