@@ -60,7 +60,7 @@ def ignore_errors(flag=None):
     Returns
     -------
     bool
-        The current value of _ignore_errors
+        The current value of _ignore_errors.
     """
     global _ignore_errors
     if flag is not None:
@@ -68,7 +68,7 @@ def ignore_errors(flag=None):
     return _ignore_errors
 
 
-def conditional_error(msg, exc=RuntimeError, category=UserWarning):
+def conditional_error(msg, exc=RuntimeError, category=UserWarning, err=None):
     """
     Raise an exception or issue a warning, depending on the value of _ignore_errors.
 
@@ -80,8 +80,11 @@ def conditional_error(msg, exc=RuntimeError, category=UserWarning):
         This exception class is used to create the exception to be raised.
     category : warning class
         This category is the class of warning to be issued.
+    err : bool
+        If None, use ignore_errors(), otherwise use value of err to determine whether to
+        raise an exception (err=True) or issue a warning (err=False).
     """
-    if ignore_errors():
+    if (err is None and ignore_errors()) or err is False:
         issue_warning(msg, category=category)
     else:
         raise exc(msg)
@@ -96,6 +99,10 @@ def ignore_errors_context(flag=True):
     ----------
     flag : bool
         If not None, set ignore_errors to this value.
+
+    Yields
+    ------
+    None
     """
     save = ignore_errors()
     ignore_errors(flag)
@@ -118,7 +125,8 @@ def simple_warning(msg, category=UserWarning, stacklevel=2):
     stacklevel : int
         Number of levels up the stack to identify as the warning location.
     """
-    warn_deprecation('simple_warning is deprecated.  Use openmdao.warnings.issue_warning instead.')
+    warn_deprecation('simple_warning is deprecated. '
+                     'Use openmdao.utils.om_warnings.issue_warning instead.')
     old_format = warnings.formatwarning
     warnings.formatwarning = _warn_simple_format
     try:
@@ -159,14 +167,6 @@ def ensure_compatible(name, value, shape=None, indices=None):
     if isinstance(value, Iterable):
         value = np.asarray(value)
 
-    if indices is not None:
-        contains_slicer = _is_slicer_op(indices)
-        if not contains_slicer:
-            indices = np.atleast_1d(np.asarray(indices, dtype=INT_DTYPE))
-            ind_shape = indices.shape
-    else:
-        contains_slicer = False
-
     # if shape is not given, infer from value (if not scalar) or indices
     if shape is not None:
         if isinstance(shape, numbers.Integral):
@@ -175,14 +175,16 @@ def ensure_compatible(name, value, shape=None, indices=None):
             shape = tuple(shape)
     elif not np.isscalar(value):
         shape = np.atleast_1d(value).shape
-    elif indices is not None:
-        if len(ind_shape) > 1:
+    if indices is not None and indices.shaped_instance() is not None:
+        if indices.src_ndim > 1 and shape is None:
             raise RuntimeError("src_indices for '%s' is not flat, so its input "
-                               "shape must be provided. src_indices may contain "
-                               "an extra dimension if the connected source is "
-                               "not flat, making the input shape ambiguous." %
-                               name)
-        shape = ind_shape
+                               "shape must be provided." % name)
+        indshape = shape2tuple(indices.shape)
+        if shape is not None and indshape != shape:
+            raise ValueError("Shape of indices %s does not match shape of %s for '%s'." %
+                             (indshape, shape, name))
+        if shape is None:
+            shape = indshape
 
     if shape is None:
         # shape is not determined, assume the shape of value was intended
@@ -200,12 +202,7 @@ def ensure_compatible(name, value, shape=None, indices=None):
                                  "Expected %s but got %s." %
                                  (name, shape, value.shape))
 
-    if indices is not None and not contains_slicer and shape != ind_shape[:len(shape)]:
-        raise ValueError("Shape of indices does not match shape for '%s': "
-                         "Expected %s but got %s." %
-                         (name, shape, ind_shape[:len(shape)]))
-
-    return value, shape, indices
+    return value, shape
 
 
 def determine_adder_scaler(ref0, ref, adder, scaler):
@@ -217,10 +214,10 @@ def determine_adder_scaler(ref0, ref, adder, scaler):
 
     Parameters
     ----------
-    ref : float or ndarray, optional
-        Value of response variable that scales to 1.0 in the driver.
     ref0 : float or ndarray, optional
         Value of response variable that scales to 0.0 in the driver.
+    ref : float or ndarray, optional
+        Value of response variable that scales to 1.0 in the driver.
     adder : float or ndarray, optional
         Value to add to the model value to get the scaled value. Adder
         is first in precedence.
@@ -231,7 +228,7 @@ def determine_adder_scaler(ref0, ref, adder, scaler):
     Returns
     -------
     tuple
-        adder and scaler, properly formatted and based on ref/ref0 if provided.
+        Adder and scaler, properly formatted and based on ref/ref0 if provided.
 
     Raises
     ------
@@ -283,14 +280,14 @@ def set_pyoptsparse_opt(optname, fallback=True):
     optname : str
         Name of pyoptsparse optimizer that is requested by the test.
     fallback : bool
-        If True, fall back to SLSQP if optname can't be found
+        If True, fall back to SLSQP if optname can't be found.
 
     Returns
     -------
     object
         Pyoptsparse optimizer instance.
     str
-        Pyoptsparse optimizer string
+        Pyoptsparse optimizer string.
     """
     OPT = None
     opt = None
@@ -422,7 +419,11 @@ def all_ancestors(pathname, delim='.'):
     pathname : str
         Pathname of starting object.
     delim : str
-        Delimiter used to split the name
+        Delimiter used to split the name.
+
+    Yields
+    ------
+    str
     """
     parts = pathname.split(delim)
     for i in range(len(parts), 0, -1):
@@ -436,7 +437,7 @@ def find_matches(pattern, var_list):
     Parameters
     ----------
     pattern : str
-        String pattern
+        String pattern.
     var_list : list of str
         List of variable names to search for pattern.
 
@@ -468,7 +469,7 @@ def pad_name(name, pad_num=10, quotes=False):
     Returns
     -------
     str
-        Padded string
+        Padded string.
     """
     l_name = len(name)
     quotes_len = 2 if quotes else 0
@@ -494,14 +495,14 @@ def run_model(prob, ignore_exception=False):
     Parameters
     ----------
     prob : Problem
-        an instance of Problem
+        An instance of Problem.
     ignore_exception : bool
         Set to True to ignore an exception of any kind.
 
     Returns
     -------
     string
-        output from calling `run_model` on the Problem, captured from stdout
+        Output from calling `run_model` on the Problem, captured from stdout.
     """
     stdout = sys.stdout
     strout = StringIO()
@@ -525,14 +526,14 @@ def run_driver(prob):
     Parameters
     ----------
     prob : Problem
-        an instance of Problem
+        An instance of Problem.
 
     Returns
     -------
-    boolean
+    bool
         Failure flag; True if failed to converge, False is successful.
     string
-        output from calling `run_driver` on the Problem, captured from stdout
+        Output from calling `run_driver` on the Problem, captured from stdout.
     """
     stdout = sys.stdout
     strout = StringIO()
@@ -555,15 +556,6 @@ def printoptions(*args, **kwds):
     options at the end. See `numpy.set_printoptions` for the full description of
     available options. If any invalid options are specified, they will be ignored.
 
-    Parameters
-    ----------
-    *args : list
-        Variable-length argument list.
-    **kwds : dict
-        Arbitrary keyword arguments.
-
-    Examples
-    --------
     >>> with printoptions(precision=2):
     ...     print(np.array([2.0])) / 3
     [0.67]
@@ -571,9 +563,20 @@ def printoptions(*args, **kwds):
     >>> with printoptions(precision=2) as opts:
     ...      assert_equal(opts, np.get_printoptions())
 
+    Parameters
+    ----------
+    *args : list
+        Variable-length argument list.
+    **kwds : dict
+        Arbitrary keyword arguments.
+
+    Yields
+    ------
+    str or int
+
     See Also
     --------
-    set_printoptions, get_printoptions
+        set_printoptions, get_printoptions
     """
     opts = np.get_printoptions()
 
@@ -588,6 +591,10 @@ def printoptions(*args, **kwds):
         np.set_printoptions(**opts)
 
 
+def _nothing():
+    yield None
+
+
 def do_nothing_context():
     """
     Do nothing.
@@ -600,10 +607,7 @@ def do_nothing_context():
     contextmanager
         A do nothing context manager.
     """
-    def nothing():
-        yield None
-
-    return contextmanager(nothing)()
+    return contextmanager(_nothing)()
 
 
 def remove_whitespace(s, right=False, left=False):
@@ -670,7 +674,7 @@ def make_serializable(o):
     Parameters
     ----------
     o : object
-        the object to be converted
+        The object to be converted.
 
     Returns
     -------
@@ -710,7 +714,7 @@ def make_serializable_key(o):
     Parameters
     ----------
     o : object
-        the object to be converted
+        The object to be converted.
 
     Returns
     -------
@@ -738,7 +742,7 @@ def default_noraise(o):
     Parameters
     ----------
     o : object
-        the object to be converted
+        The object to be converted.
 
     Returns
     -------
@@ -1061,7 +1065,7 @@ def convert_src_inds(parent_src_inds, parent_src_shape, my_src_inds, my_src_shap
     parent_src_shape : tuple
         Shape of source expected by parent.
     my_src_inds : ndarray or fancy index
-        src_indices at the current system level, before conversion.
+        Src_indices at the current system level, before conversion.
     my_src_shape : tuple
         Expected source shape at the current system level.
 
@@ -1074,19 +1078,12 @@ def convert_src_inds(parent_src_inds, parent_src_shape, my_src_inds, my_src_shap
         return my_src_inds
     elif my_src_inds is None:
         return parent_src_inds
-    if isinstance(my_src_inds, tuple):
-        ndims = len(my_src_inds)
-    elif isinstance(my_src_inds, np.ndarray):
-        ndims = my_src_inds.ndim
-    else:  # slice
-        ndims = 1
-    if _is_slicer_op(parent_src_inds):
-        parent_src_inds = _slice_indices(parent_src_inds, np.prod(parent_src_shape),
-                                         parent_src_shape)
+    ndims = my_src_inds.src_ndim
+
     if ndims == 1:
-        return parent_src_inds.ravel()[my_src_inds]
+        return parent_src_inds.shaped_array()[my_src_inds()]
     else:
-        return parent_src_inds.reshape(my_src_shape)[my_src_inds]
+        return parent_src_inds.shaped_array().reshape(my_src_shape)[my_src_inds()]
 
 
 def shape_from_idx(src_shape, src_inds, flat_src_inds):
@@ -1196,20 +1193,22 @@ def get_connection_owner(system, tgt):
     Returns
     -------
     tuple
-        (owning group, promoted source name, promoted target name)
+        (wning group, promoted source name, promoted target name).
     """
     from openmdao.core.group import Group
 
     model = system._problem_meta['model_ref']()
     src = model._conn_global_abs_in2out[tgt]
+    abs2prom = model._var_allprocs_abs2prom
 
-    if model._var_allprocs_abs2prom['input'][tgt] != model._var_allprocs_abs2prom['output'][src]:
-        # connection is explicit
-        for g in model.system_iter(include_self=True, recurse=True, typ=Group):
-            if g._manual_connections:
-                tprom = g._var_allprocs_abs2prom['input'][tgt]
-                if tprom in g._manual_connections:
-                    return g.pathname, g._var_allprocs_abs2prom['output'][src], tprom
+    if src in abs2prom['output'] and tgt in abs2prom['input'][tgt]:
+        if abs2prom['input'][tgt] != abs2prom['output'][src]:
+            # connection is explicit
+            for g in model.system_iter(include_self=True, recurse=True, typ=Group):
+                if g._manual_connections:
+                    tprom = g._var_allprocs_abs2prom['input'][tgt]
+                    if tprom in g._manual_connections:
+                        return g.pathname, g._var_allprocs_abs2prom['output'][src], tprom
 
     return None, None, None
 
@@ -1239,6 +1238,16 @@ class LocalRangeIterable(object):
     The number of iterations for a distributed variable will be the full distributed size of the
     variable but None will be returned for any indices that are not local to the given rank.
 
+    Parameters
+    ----------
+    system : System
+        Containing System.
+    vname : str
+        Name of the variable.
+    use_vec_offset : bool
+        If True, return indices for the given variable within its vector, else just return
+        indices within the variable itself, i.e. range(var_size).
+
     Attributes
     ----------
     _inds : ndarray
@@ -1258,16 +1267,6 @@ class LocalRangeIterable(object):
     def __init__(self, system, vname, use_vec_offset=True):
         """
         Initialize the iterator.
-
-        Parameters
-        ----------
-        system : System
-            Containing System.
-        vname : str
-            Name of the variable.
-        use_vec_offset : bool
-            If True, return indices for the given variable within its vector, else just return
-            indices within the variable itself, i.e. range(var_size).
         """
         self._dist_size = 0
 
