@@ -1,6 +1,5 @@
 """Define the default Transfer class."""
 
-from itertools import product, chain
 from collections import defaultdict
 
 import numpy as np
@@ -8,7 +7,6 @@ import numpy as np
 from openmdao.core.constants import INT_DTYPE
 from openmdao.vectors.transfer import Transfer
 from openmdao.utils.array_utils import convert_neg, _global2local_offsets
-from openmdao.utils.general_utils import _is_slicer_op
 from openmdao.utils.mpi import MPI
 
 _empty_idx_array = np.array([], dtype=INT_DTYPE)
@@ -24,6 +22,19 @@ def _merge(indices_list):
 class DefaultTransfer(Transfer):
     """
     Default NumPy transfer.
+
+    Parameters
+    ----------
+    in_vec : <Vector>
+        Pointer to the input vector.
+    out_vec : <Vector>
+        Pointer to the output vector.
+    in_inds : int ndarray
+        Input indices for the transfer.
+    out_inds : int ndarray
+        Output indices for the transfer.
+    comm : MPI.Comm or <FakeComm>
+        Communicator of the system that owns this transfer.
     """
 
     @staticmethod
@@ -86,8 +97,7 @@ class DefaultTransfer(Transfer):
                 # Read in and process src_indices
                 src_indices = meta_in['src_indices']
                 if src_indices is not None:
-                    if src_indices.ndim == 1:
-                        src_indices = convert_neg(src_indices, meta_out['global_size'])
+                    src_indices = src_indices.shaped_array()
 
                 # 1. Compute the output indices
                 offset = offsets_out[idx_out]
@@ -253,7 +263,7 @@ class DefaultTransfer(Transfer):
         """
         if mode == 'fwd':
             # this works whether the vecs have multi columns or not due to broadcasting
-            in_vec.set_val(out_vec.asarray()[self._out_inds], self._in_inds)
+            in_vec.set_val(out_vec.asarray()[self._out_inds.flat], self._in_inds)
 
         else:  # rev
             out_vec.iadd(np.bincount(self._out_inds, in_vec._get_data()[self._in_inds],
